@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class ExpressionOp extends Expression {
@@ -140,40 +140,30 @@ public class ExpressionOp extends Expression {
      */
     ExpressionOp(Expression e) {
 
-        super(e.dataType.isDateTimeTypeWithZone() ? OpTypes.CAST
-                                                  : OpTypes.ZONE_MODIFIER);
+        super(OpTypes.CAST);
+
+        nodes       = new Expression[UNARY];
+        nodes[LEFT] = e;
 
         switch (e.dataType.typeCode) {
 
             case Types.SQL_TIME_WITH_TIME_ZONE :
-                nodes                = new Expression[UNARY];
-                nodes[LEFT] = new ExpressionOp(OpTypes.ZONE_MODIFIER, e, null);
-                nodes[LEFT].dataType = e.dataType;
                 dataType = DateTimeType.getDateTimeType(Types.SQL_TIME,
                         e.dataType.scale);
                 break;
 
             case Types.SQL_TIMESTAMP_WITH_TIME_ZONE :
-                nodes                = new Expression[UNARY];
-                nodes[LEFT] = new ExpressionOp(OpTypes.ZONE_MODIFIER, e, null);
-                nodes[LEFT].dataType = e.dataType;
                 dataType = DateTimeType.getDateTimeType(Types.SQL_TIMESTAMP,
                         e.dataType.scale);
                 break;
 
             case Types.SQL_TIME :
-                nodes                = new Expression[BINARY];
-                nodes[LEFT]          = e;
-                nodes[LEFT].dataType = e.dataType;
                 dataType =
                     DateTimeType.getDateTimeType(Types.SQL_TIME_WITH_TIME_ZONE,
                                                  e.dataType.scale);
                 break;
 
             case Types.SQL_TIMESTAMP :
-                nodes                = new Expression[BINARY];
-                nodes[LEFT]          = e;
-                nodes[LEFT].dataType = e.dataType;
                 dataType = DateTimeType.getDateTimeType(
                     Types.SQL_TIMESTAMP_WITH_TIME_ZONE, e.dataType.scale);
                 break;
@@ -471,23 +461,15 @@ public class ExpressionOp extends Expression {
                 }
 
                 if (nodes[RIGHT] != null) {
-                    if (nodes[RIGHT].dataType == null) {
+                    Type rightDataType = nodes[RIGHT].dataType;
+
+                    if (rightDataType == null) {
                         nodes[RIGHT].dataType =
                             Type.SQL_INTERVAL_HOUR_TO_MINUTE;
-                    }
-
-                    if (nodes[RIGHT].dataType.typeCode
-                            != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
-                        if (nodes[RIGHT].opType == OpTypes.VALUE) {
-                            nodes[RIGHT].valueData =
-                                Type.SQL_INTERVAL_HOUR_TO_MINUTE.castToType(
-                                    session, nodes[RIGHT].valueData,
-                                    nodes[RIGHT].dataType);
-                            nodes[RIGHT].dataType =
-                                Type.SQL_INTERVAL_HOUR_TO_MINUTE;
-                        } else {
-                            throw Error.error(ErrorCode.X_42563);
-                        }
+                    } else if (!rightDataType.isCharacterType()
+                               && rightDataType.typeCode
+                                  != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
+                        throw Error.error(ErrorCode.X_42563);
                     }
                 }
 
@@ -969,18 +951,36 @@ public class ExpressionOp extends Expression {
                     return null;
                 }
 
-                if (nodes[RIGHT] != null && rightValue == null) {
+                boolean atLocal = nodes[RIGHT] == null;
+
+                if (atLocal) {
+                    return ((DateTimeType) dataType).changeZone(session,
+                            leftValue, nodes[LEFT].dataType, 0, atLocal);
+                }
+
+                if (rightValue == null) {
                     return null;
                 }
 
-                long zoneSeconds = nodes[RIGHT] == null
-                                   ? session.getZoneSeconds()
-                                   : ((IntervalType) nodes[RIGHT].dataType)
-                                       .getSeconds(rightValue);
+                if (nodes[RIGHT].dataType.isCharacterType()) {
+                    if (DateTimeType.zoneIDs.contains(rightValue)) {
+                        return ((DateTimeType) dataType).changeZone(session,
+                                leftValue, nodes[LEFT].dataType,
+                                (String) rightValue);
+                    } else {
+                        rightValue =
+                            Type.SQL_INTERVAL_HOUR_TO_MINUTE
+                                .convertToDefaultType(session, rightValue);
+                    }
+                }
+
+                long zoneSeconds =
+                    ((IntervalType) nodes[RIGHT].dataType).getSeconds(
+                        rightValue);
 
                 return ((DateTimeType) dataType).changeZone(session,
                         leftValue, nodes[LEFT].dataType, (int) zoneSeconds,
-                        session.getZoneSeconds());
+                        false);
             }
             case OpTypes.LIMIT :
 
