@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.types.Types;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class ParserBase {
@@ -61,7 +61,6 @@ public class ParserBase {
     protected int           partPosition;
     protected HsqlException lastError;
     protected HsqlName      lastSynonym;
-    protected boolean       isCheckOrTriggerCondition;
     protected boolean       isSchemaDefinition;
     protected boolean       isViewDefinition;
     protected boolean       isRecording;
@@ -106,13 +105,12 @@ public class ParserBase {
         scanner.reset(session, sql);
 
         //
-        partPosition              = 0;
-        lastError                 = null;
-        lastSynonym               = null;
-        isCheckOrTriggerCondition = false;
-        isSchemaDefinition        = false;
-        isViewDefinition          = false;
-        isRecording               = false;
+        partPosition       = 0;
+        lastError          = null;
+        lastSynonym        = null;
+        isSchemaDefinition = false;
+        isViewDefinition   = false;
+        isRecording        = false;
 
         recordedStatement.clear();
     }
@@ -401,19 +399,39 @@ public class ParserBase {
         }
     }
 
+    void checkIsIntegral() {
+
+        if (!isIntegral()) {
+            throw unexpectedTokenRequire("an integer");
+        }
+    }
+
     void checkIsQuotedString() {
 
-        if (token.tokenType != Tokens.X_VALUE
-                || !token.dataType.isCharacterType()) {
-            throw unexpectedToken();
+        if (!isQuotedString()) {
+            throw unexpectedTokenRequire("a quoted string");
         }
     }
 
+    boolean isIntegral() {
+        return token.tokenType == Tokens.X_VALUE
+               && token.dataType.isIntegralType();
+    }
+
+    boolean isQuotedString() {
+        return token.tokenType == Tokens.X_VALUE
+               && token.dataType.isCharacterType();
+    }
+
     void checkIsThis(int type) {
 
         if (token.tokenType != type) {
             String required = Tokens.getKeyword(type);
 
+            if (required == null) {
+                required = "";
+            }
+
             throw unexpectedTokenRequire(required);
         }
     }
@@ -450,11 +468,7 @@ public class ParserBase {
 
     String readQuotedString() {
 
-        checkIsValue();
-
-        if (!token.dataType.isCharacterType()) {
-            throw Error.error(ErrorCode.X_42563);
-        }
+        checkIsQuotedString();
 
         String value = token.tokenString;
 
@@ -505,6 +519,39 @@ public class ParserBase {
         return false;
     }
 
+    void readAny(int id1, int id2, int id3, int id4) {
+        read();
+        checkIsAny(id1, id2, id3, id4);
+    }
+
+    void checkIsAny(int id1, int id2, int id3, int id4) {
+
+        if (token.tokenType == id1 || token.tokenType == id2
+                || token.tokenType == id3 || token.tokenType == id4) {
+            return;
+        }
+
+        String required = "";
+
+        if (id1 != 0) {
+            required += Tokens.getKeyword(id1);
+
+            if (id2 != 0) {
+                required += " or " + Tokens.getKeyword(id2);
+            }
+
+            if (id3 != 0) {
+                required += " or " + Tokens.getKeyword(id3);
+            }
+
+            if (id4 != 0) {
+                required += " or " + Tokens.getKeyword(id4);
+            }
+        }
+
+        throw unexpectedTokenRequire(required);
+    }
+
     Integer readIntegerObject() {
 
         int value = readInteger();
@@ -522,7 +569,7 @@ public class ParserBase {
             read();
         }
 
-        checkIsValue();
+        checkIsIntegral();
 
         if (minus && token.dataType.typeCode == Types.SQL_BIGINT
                 && ((Number) token.tokenValue).longValue()
