@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.IndexStats;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.persist.HsqlDatabaseProperties;
@@ -54,7 +54,7 @@ import org.hsqldb.types.Types;
  * Parser for session and management statements
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class ParserCommand extends ParserDDL {
@@ -107,7 +107,7 @@ public class ParserCommand extends ParserDDL {
             }
 
             cs.setCompileTimestamp(
-                database.txManager.getGlobalChangeTimestamp());
+                database.txManager.getSystemChangeNumber());
             list.add(cs);
         }
 
@@ -297,17 +297,7 @@ public class ParserCommand extends ParserDDL {
                 break;
 
             case Tokens.EXPLAIN : {
-                int position = getPosition();
-
-                read();
-
-                if (token.tokenType == Tokens.PLAN) {
-                    cs = compileExplainPlan();
-                } else {
-                    cs = compileExplainReferences();
-                }
-
-                cs.setSQL(getLastPart(position));
+                cs = compileExplain();
 
                 break;
             }
@@ -388,6 +378,7 @@ public class ParserCommand extends ParserDDL {
 
         if (extended) {
             readThis(Tokens.FOR);
+            checkIsAny(Tokens.DATABASE, Tokens.TABLE, 0, 0);
 
             if (readIfThis(Tokens.DATABASE)) {
                 switch (token.tokenType) {
@@ -823,13 +814,7 @@ public class ParserCommand extends ParserDDL {
                                             args);
             }
             case Tokens.AUTOCOMMIT : {
-                read();
-
-                Boolean  mode = processTrueOrFalseObject();
-                Object[] args = new Object[]{ mode };
-
-                return new StatementSession(
-                    StatementTypes.SET_SESSION_AUTOCOMMIT, args);
+                return compileSetAutoCommit();
             }
 
             // deprecated
@@ -990,6 +975,44 @@ public class ParserCommand extends ParserDDL {
         }
     }
 
+    StatementSession compileSetAutoCommit() {
+
+        read();
+
+        boolean mode = false;
+        int     rows = -1;
+
+        switch (token.tokenType) {
+
+            case Tokens.TRUE :
+            case Tokens.FALSE :
+                mode = processTrueOrFalse();
+                break;
+
+            case Tokens.AT :
+                read();
+
+                rows = readInteger();
+
+                if (rows < 0) {
+                    throw Error.error(ErrorCode.X_22003);
+                }
+
+                readThis(Tokens.ROWS);
+                break;
+
+            default :
+                throw unexpectedToken();
+        }
+
+        Object[] args = new Object[] {
+            mode, rows
+        };
+
+        return new StatementSession(StatementTypes.SET_SESSION_AUTOCOMMIT,
+                                    args);
+    }
+
     StatementCommand compileSetTable() {
 
         read();
@@ -1214,7 +1237,23 @@ public class ParserCommand extends ParserDDL {
 
                 Integer  value = readIntegerObject();
                 Object[] args  = new Object[] {
-                    value, Boolean.valueOf(sqlLog)
+                    value, Boolean.valueOf(sqlLog), Boolean.TRUE
+                };
+
+                return new StatementCommand(
+                    StatementTypes.SET_DATABASE_FILES_EVENT_LOG, args, null,
+                    null);
+            }
+            case Tokens.EXTERNAL : {
+                read();
+                readThis(Tokens.EVENT);
+                readThis(Tokens.LOG);
+
+                readThis(Tokens.LEVEL);
+
+                Integer  value = readIntegerObject();
+                Object[] args  = new Object[] {
+                    value, Boolean.FALSE, Boolean.FALSE
                 };
 
                 return new StatementCommand(
@@ -1282,80 +1321,12 @@ public class ParserCommand extends ParserDDL {
 
                 switch (token.tokenType) {
 
-                    case Tokens.RESTRICT :
+                    case Tokens.AVG :
                         read();
-                        readThis(Tokens.EXEC);
+                        readThis(Tokens.SCALE);
 
-                        property = HsqlDatabaseProperties.sql_restrict_exec;
-                        flag     = processTrueOrFalseObject();
-                        break;
-
-                    case Tokens.LIVE :
-                        read();
-                        readThis(Tokens.OBJECT);
-
-                        property = HsqlDatabaseProperties.sql_live_object;
-                        flag     = processTrueOrFalseObject();
-                        break;
-
-                    case Tokens.NAMES :
-                        read();
-
-                        property = HsqlDatabaseProperties.sql_enforce_names;
-                        flag     = processTrueOrFalseObject();
-                        break;
-
-                    case Tokens.REGULAR :
-                        read();
-                        readThis(Tokens.NAMES);
-
-                        property = HsqlDatabaseProperties.sql_regular_names;
-                        flag     = processTrueOrFalseObject();
-                        break;
-
-                    case Tokens.REFERENCES :
-                        read();
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_enforce_refs;
-                        break;
-
-                    case Tokens.SIZE :
-                        read();
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_enforce_size;
-                        break;
-
-                    case Tokens.TYPES :
-                        read();
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_enforce_types;
-                        break;
-
-                    case Tokens.TDC :
-                        read();
-
-                        if (readIfThis(Tokens.DELETE)) {
-                            property = HsqlDatabaseProperties.sql_enforce_tdcd;
-                        } else {
-                            readThis(Tokens.UPDATE);
-
-                            property = HsqlDatabaseProperties.sql_enforce_tdcu;
-                        }
-
-                        flag = processTrueOrFalseObject();
-                        break;
-
-                    case Tokens.TRANSLATE :
-                        read();
-                        readThis(Tokens.TTI);
-                        readThis(Tokens.TYPES);
-
-                        flag = processTrueOrFalseObject();
-                        property =
-                            HsqlDatabaseProperties.jdbc_translate_tti_types;
+                        value    = readIntegerObject();
+                        property = HsqlDatabaseProperties.sql_avg_scale;
                         break;
 
                     case Tokens.CHARACTER :
@@ -1374,6 +1345,70 @@ public class ParserCommand extends ParserDDL {
                         property = HsqlDatabaseProperties.sql_concat_nulls;
                         break;
 
+                    case Tokens.CONVERT :
+                        read();
+                        readThis(Tokens.TRUNCATE);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_convert_trunc;
+                        break;
+
+                    case Tokens.DOUBLE :
+                        read();
+                        readThis(Tokens.NAN);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_double_nan;
+                        break;
+
+                    case Tokens.IGNORECASE :
+                        read();
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_ignore_case;
+                        break;
+
+                    case Tokens.LIVE :
+                        read();
+                        readThis(Tokens.OBJECT);
+
+                        property = HsqlDatabaseProperties.sql_live_object;
+                        flag     = processTrueOrFalseObject();
+                        break;
+
+                    case Tokens.LONGVAR :
+                        read();
+                        readThis(Tokens.IS);
+                        readThis(Tokens.LOB);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_longvar_is_lob;
+                        break;
+
+                    case Tokens.LOWER :
+                        read();
+                        readThis(Tokens.CASE);
+                        readThis(Tokens.IDENTIFIER);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_lowercase_ident;
+                        break;
+
+                    case Tokens.MAX :
+                        read();
+                        readThis(Tokens.RECURSIVE);
+
+                        value    = readIntegerObject();
+                        property = HsqlDatabaseProperties.sql_max_recursive;
+                        break;
+
+                    case Tokens.NAMES :
+                        read();
+
+                        property = HsqlDatabaseProperties.sql_enforce_names;
+                        flag     = processTrueOrFalseObject();
+                        break;
+
                     case Tokens.NULLS :
                         read();
 
@@ -1388,52 +1423,34 @@ public class ParserCommand extends ParserDDL {
                         flag = processTrueOrFalseObject();
                         break;
 
-                    case Tokens.UNIQUE :
+                    case Tokens.REGULAR :
                         read();
-                        readThis(Tokens.NULLS);
+                        readThis(Tokens.NAMES);
 
+                        property = HsqlDatabaseProperties.sql_regular_names;
                         flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_unique_nulls;
                         break;
 
-                    case Tokens.CONVERT :
-                        read();
-                        readThis(Tokens.TRUNCATE);
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_convert_trunc;
-                        break;
-
-                    case Tokens.AVG :
-                        read();
-                        readThis(Tokens.SCALE);
-
-                        value    = readIntegerObject();
-                        property = HsqlDatabaseProperties.sql_avg_scale;
-                        break;
-
-                    case Tokens.DOUBLE :
-                        read();
-                        readThis(Tokens.NAN);
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_double_nan;
-                        break;
-
-                    case Tokens.LONGVAR :
-                        read();
-                        readThis(Tokens.IS);
-                        readThis(Tokens.LOB);
-
-                        flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_longvar_is_lob;
-                        break;
-
-                    case Tokens.IGNORECASE :
+                    case Tokens.REFERENCES :
                         read();
 
                         flag     = processTrueOrFalseObject();
-                        property = HsqlDatabaseProperties.sql_ignore_case;
+                        property = HsqlDatabaseProperties.sql_enforce_refs;
+                        break;
+
+                    case Tokens.RESTRICT :
+                        read();
+                        readThis(Tokens.EXEC);
+
+                        property = HsqlDatabaseProperties.sql_restrict_exec;
+                        flag     = processTrueOrFalseObject();
+                        break;
+
+                    case Tokens.SIZE :
+                        read();
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_enforce_size;
                         break;
 
                     case Tokens.SYNTAX :
@@ -1466,16 +1483,62 @@ public class ParserCommand extends ParserDDL {
                         flag = processTrueOrFalseObject();
                         break;
 
-                    case Tokens.SYS : {
+                    case Tokens.SYS :
                         read();
                         readThis(Tokens.INDEX);
                         readThis(Tokens.NAMES);
 
                         flag     = processTrueOrFalseObject();
                         property = HsqlDatabaseProperties.sql_sys_index_names;
-
                         break;
-                    }
+
+                    case Tokens.TDC :
+                        read();
+
+                        if (readIfThis(Tokens.DELETE)) {
+                            property = HsqlDatabaseProperties.sql_enforce_tdcd;
+                        } else {
+                            readThis(Tokens.UPDATE);
+
+                            property = HsqlDatabaseProperties.sql_enforce_tdcu;
+                        }
+
+                        flag = processTrueOrFalseObject();
+                        break;
+
+                    case Tokens.TRANSLATE :
+                        read();
+                        readThis(Tokens.TTI);
+                        readThis(Tokens.TYPES);
+
+                        flag = processTrueOrFalseObject();
+                        property =
+                            HsqlDatabaseProperties.jdbc_translate_tti_types;
+                        break;
+
+                    case Tokens.TRUNCATE :
+                        read();
+                        readThis(Tokens.TRAILING);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_trunc_trailing;
+                        break;
+
+                    case Tokens.TYPES :
+                        read();
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_enforce_types;
+                        break;
+
+                    case Tokens.UNIQUE :
+                        read();
+                        readThis(Tokens.NULLS);
+
+                        flag     = processTrueOrFalseObject();
+                        property = HsqlDatabaseProperties.sql_unique_nulls;
+                        break;
+
                     default :
                         throw unexpectedToken();
                 }
@@ -1597,7 +1660,7 @@ public class ParserCommand extends ParserDDL {
 
         int        type  = 0;
         Boolean    flag  = null;
-        Integer    value = null;
+        Object     value = null;
         Boolean    mode  = null;
         HsqlName[] names = database.schemaManager.getCatalogNameArray();
 
@@ -1608,7 +1671,7 @@ public class ParserCommand extends ParserDDL {
             case Tokens.CHECK : {
                 read();
 
-                long longValue  = readBigint();
+                long longValue1 = readBigint();
                 long longValue2 = -1;
 
                 type  = StatementTypes.SET_DATABASE_FILES_CHECK;
@@ -1620,7 +1683,7 @@ public class ParserCommand extends ParserDDL {
 
                 Object[] args = new Object[2];
 
-                args[0] = Long.valueOf(longValue);
+                args[0] = Long.valueOf(longValue1);
                 args[1] = Long.valueOf(longValue2);
 
                 return new StatementCommand(type, args, null, names);
@@ -1742,7 +1805,7 @@ public class ParserCommand extends ParserDDL {
                 readThis(Tokens.PATH);
 
                 type  = StatementTypes.SET_DATABASE_FILES_TEMP_PATH;
-                value = readIntegerObject();
+                value = readQuotedString();
 
                 break;
             }
@@ -1817,6 +1880,8 @@ public class ParserCommand extends ParserDDL {
         boolean  readonly = false;
         Object[] args     = new Object[2];
 
+        checkIsAny(Tokens.READ, Tokens.ISOLATION, 0, 0);
+
         outerloop:
         while (true) {
             switch (token.tokenType) {
@@ -1849,6 +1914,8 @@ public class ParserCommand extends ParserDDL {
 
                     read();
                     readThis(Tokens.LEVEL);
+                    checkIsAny(Tokens.SERIALIZABLE, Tokens.READ,
+                               Tokens.REPEATABLE, 0);
 
                     switch (token.tokenType) {
 
@@ -1859,7 +1926,8 @@ public class ParserCommand extends ParserDDL {
                             break;
 
                         case Tokens.READ :
-                            read();
+                            readAny(Tokens.COMMITTED, Tokens.UNCOMMITTED, 0,
+                                    0);
 
                             if (token.tokenType == Tokens.COMMITTED) {
                                 read();
@@ -1913,8 +1981,6 @@ public class ParserCommand extends ParserDDL {
 
     /**
      * Responsible for  handling the execution of COMMIT [WORK]
-     *
-     * @throws  HsqlException
      */
     private Statement compileCommit() {
 
@@ -2116,6 +2182,9 @@ public class ParserCommand extends ParserDDL {
 
     private Statement compileSessionSettings() {
 
+        checkIsAny(Tokens.CHARACTERISTICS, Tokens.AUTHORIZATION,
+                   Tokens.RESULT, Tokens.FEATURE);
+
         switch (token.tokenType) {
 
             case Tokens.CHARACTERISTICS : {
@@ -2220,26 +2289,37 @@ public class ParserCommand extends ParserDDL {
 
         readThis(Tokens.ZONE);
 
-        if (token.tokenType == Tokens.LOCAL) {
-            read();
+        switch (token.tokenType) {
 
-            e = new ExpressionValue(null, Type.SQL_INTERVAL_HOUR_TO_MINUTE);
-        } else {
-            e = XreadIntervalValueExpression();
+            case Tokens.LOCAL : {
+                read();
 
-            HsqlList unresolved = e.resolveColumnReferences(session,
-                RangeGroup.emptyGroup, RangeGroup.emptyArray, null);
+                e = new ExpressionValue(null,
+                                        Type.SQL_INTERVAL_HOUR_TO_MINUTE);
 
-            ExpressionColumn.checkColumnsResolved(unresolved);
-            e.resolveTypes(session, null);
-
-            if (e.dataType == null) {
-                throw Error.error(ErrorCode.X_42563);
+                break;
             }
+            case Tokens.INTERVAL : {
+                e = XreadIntervalValueExpression();
 
-            if (e.dataType.typeCode != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
-                throw Error.error(ErrorCode.X_42563);
+                List unresolved = e.resolveColumnReferences(session,
+                    RangeGroup.emptyGroup, RangeGroup.emptyArray, null);
+
+                ExpressionColumn.checkColumnsResolved(unresolved);
+                e.resolveTypes(session, null);
+
+                if (e.dataType == null) {
+                    throw Error.error(ErrorCode.X_42563);
+                }
+
+                if (e.dataType.typeCode != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
+                    throw Error.error(ErrorCode.X_42563);
+                }
+
+                break;
             }
+            default :
+                e = XreadValueExpression();
         }
 
         return new StatementSession(session, compileContext,
@@ -2311,7 +2391,7 @@ public class ParserCommand extends ParserDDL {
         path = readQuotedString();
         path = path.trim();
 
-        if (path.length() == 0) {
+        if (path.isEmpty()) {
             throw unexpectedToken(path);
         }
 
@@ -2425,80 +2505,106 @@ public class ParserCommand extends ParserDDL {
 
     private Statement compilePerform() {
 
-        read();
+        readAny(Tokens.CHECK, Tokens.EXPORT, Tokens.IMPORT, 0);
 
         switch (token.tokenType) {
 
-            /**
-             * PERFORM CHECK TABLE <name> INDEX [AND FIX]
-             * PERFORM CHECK ALL TABLE INDEX [AND FIX]
-             */
-            case Tokens.CHECK : {
-                read();
+            case Tokens.CHECK :
+                return compileCheck();
 
-                boolean  isAll     = false;
-                HsqlName tableName = null;
-                Integer  type      = Integer.valueOf(IndexStats.checkRows);
-                Integer  number    = Integer.valueOf(-1);
+            case Tokens.IMPORT :
+                readAny(Tokens.SCRIPT, Tokens.DATA, 0, 0);
 
-                switch (token.tokenType) {
-
-                    case Tokens.ALL : {
-                        read();
-
-                        isAll = true;
-                    }
-
-                    // fall through
-                    case Tokens.TABLE : {
-                        readThis(Tokens.TABLE);
-
-                        if (isAll) {
-                            readThis(Tokens.INDEX);
-                        } else {
-                            tableName = readTableName().getName();
-
-                            readThis(Tokens.INDEX);
-                        }
-                    }
+                if (token.tokenType == Tokens.SCRIPT) {
+                    return compileImportScript();
+                } else {
+                    return compileImportData();
                 }
+            case Tokens.EXPORT :
+                readAny(Tokens.SCRIPT, Tokens.DATA, 0, 0);
 
-                if (readIfThis(Tokens.AND)) {
-                    readThis("FIX");
-
-                    type = Integer.valueOf(IndexStats.fixAll);
+                if (token.tokenType == Tokens.SCRIPT) {
+                    return compileScript(true);
+                } else {
+                    return compileExportData();
                 }
-
-                Object[] args = new Object[] {
-                    tableName, type, number
-                };
-                HsqlName[] names =
-                    isAll
-                    ? database.schemaManager.getCatalogAndBaseTableNames()
-                    : database.schemaManager.getCatalogAndBaseTableNames(
-                        tableName);
-
-                return new StatementCommand(StatementTypes.CHECK_INDEX, args,
-                                            null, names);
-            }
-            case Tokens.IMPORT : {
-                read();
-
-                return compileImportScript();
-            }
-            case Tokens.EXPORT : {
-                return compileExport();
-            }
             default :
                 throw unexpectedToken();
         }
     }
 
-    private Statement compileExport() {
+    /*
+     * PERFORM CHECK TABLE <name> INDEX [AND FIX]
+     * PERFORM CHECK ALL TABLE INDEX [AND FIX]
+     */
+    private Statement compileCheck() {
 
-        read();
+        readAny(Tokens.ALL, Tokens.TABLE, 0, 0);
 
-        return compileScript(true);
+        boolean  isAll     = false;
+        HsqlName tableName = null;
+        Integer  type      = Integer.valueOf(IndexStats.checkRows);
+        Integer  number    = Integer.valueOf(-1);
+
+        switch (token.tokenType) {
+
+            case Tokens.ALL : {
+                read();
+
+                isAll = true;
+            }
+
+            // fall through
+            case Tokens.TABLE : {
+                readThis(Tokens.TABLE);
+
+                if (isAll) {
+                    readThis(Tokens.INDEX);
+                } else {
+                    tableName = readTableName().getName();
+
+                    readThis(Tokens.INDEX);
+                }
+            }
+        }
+
+        if (readIfThis(Tokens.AND)) {
+            readThis("FIX");
+
+            type = Integer.valueOf(IndexStats.fixAll);
+        }
+
+        Object[] args = new Object[] {
+            tableName, type, number
+        };
+        HsqlName[] names =
+            isAll ? database.schemaManager.getCatalogAndBaseTableNames()
+                  : database.schemaManager.getCatalogAndBaseTableNames(
+                      tableName);
+
+        return new StatementCommand(StatementTypes.CHECK_INDEX, args, null,
+                                    names);
+    }
+
+    private Statement compileExportData() {
+
+        readThis(Tokens.DATA);
+        readThis(Tokens.FROM);
+        readThis(Tokens.TABLE);
+
+        HsqlName tableName = readTableName().getName();
+
+        readThis(Tokens.TO);
+
+        String fileName = readQuotedString();
+        HsqlName[] names =
+            database.schemaManager.getCatalogAndBaseTableNames();
+        Object[] args = new Object[] {
+            tableName, fileName
+        };
+
+        return new StatementCommand(StatementTypes.UNLOAD_DATA, args, null,
+                                    names);
     }
 
     private Statement compileImportScript() {
@@ -2508,6 +2614,7 @@ public class ParserCommand extends ParserDDL {
         Boolean isVersioning = Boolean.FALSE;
 
         readThis(Tokens.SCRIPT);
+        checkIsAny(Tokens.VERSIONING, Tokens.DATA, 0, 0);
 
         if (token.tokenType == Tokens.VERSIONING) {
             readThis(Tokens.VERSIONING);
@@ -2534,10 +2641,34 @@ public class ParserCommand extends ParserDDL {
                                     names);
     }
 
+    private Statement compileImportData() {
+
+        readThis(Tokens.DATA);
+        readThis(Tokens.INTO);
+        readThis(Tokens.TABLE);
+
+        HsqlName tableName = readTableName().getName();
+
+        readThis(Tokens.FROM);
+
+        String fileName = readQuotedString();
+        int    mode     = readLoadMode();
+        HsqlName[] names =
+            database.schemaManager.getCatalogAndBaseTableNames();
+        Object[] args = new Object[] {
+            tableName, fileName, Integer.valueOf(mode)
+        };
+
+        return new StatementCommand(StatementTypes.LOAD_DATA, args, null,
+                                    names);
+    }
+
     private int readLoadMode() {
 
         int mode = -1;
 
+        checkIsAny(Tokens.CONTINUE, Tokens.STOP, Tokens.CHECK, 0);
+
         switch (token.tokenType) {
 
             case Tokens.CONTINUE :
@@ -2605,7 +2736,7 @@ public class ParserCommand extends ParserDDL {
         Statement cs = new StatementCommand(StatementTypes.DATABASE_CHECKPOINT,
                                             args, null, names);
 
-        cs.setCompileTimestamp(database.txManager.getGlobalChangeTimestamp());
+        cs.setCompileTimestamp(database.txManager.getSystemChangeNumber());
         cs.setSQL(Tokens.T_CHECKPOINT);
 
         return cs;
@@ -2621,6 +2752,24 @@ public class ParserCommand extends ParserDDL {
         return cs;
     }
 
+    private Statement compileExplain() {
+
+        Statement cs;
+        int       position = getPosition();
+
+        readAny(Tokens.PLAN, Tokens.REFERENCES, 0, 0);
+
+        if (token.tokenType == Tokens.PLAN) {
+            cs = compileExplainPlan();
+        } else {
+            cs = compileExplainReferences();
+        }
+
+        cs.setSQL(getLastPart(position));
+
+        return cs;
+    }
+
     private Statement compileExplainPlan() {
 
         Statement cs;
@@ -2641,7 +2790,7 @@ public class ParserCommand extends ParserDDL {
         SchemaObject object;
         boolean      referencesFrom = false;
 
-        readThis(Tokens.REFERENCES);
+        readAny(Tokens.TO, Tokens.FROM, 0, 0);
 
         if (!readIfThis(Tokens.TO)) {
             readThis(Tokens.FROM);
