@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,10 +39,10 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.HashMap;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HashSet;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.lib.OrderedLongHashSet;
@@ -55,7 +55,7 @@ import org.hsqldb.types.Type;
  * Metadata for range variables, including conditions.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class RangeVariable {
@@ -124,7 +124,7 @@ public class RangeVariable {
     boolean isViewSubquery;
 
     // for variable and parameter lists
-    HashMappedList variables;
+    OrderedHashMap variables;
 
     // variable, parameter, table
     int rangeType;
@@ -132,7 +132,7 @@ public class RangeVariable {
     //
     boolean isGenerated;
 
-    public RangeVariable(HashMappedList variables, SimpleName rangeName,
+    public RangeVariable(OrderedHashMap variables, SimpleName rangeName,
                          boolean isVariable, int rangeType) {
 
         this.variables   = variables;
@@ -695,6 +695,10 @@ public class RangeVariable {
         return joinCondition;
     }
 
+    public void setJoinCondition(Expression e) {
+        joinCondition = e;
+    }
+
     public void addJoinCondition(Expression e) {
         joinCondition = ExpressionLogical.andExpressions(joinCondition, e);
     }
@@ -746,6 +750,23 @@ public class RangeVariable {
         return set;
     }
 
+    OrderedHashSet collectRangeVariables(RangeVariable[] rangeVars,
+                                         OrderedHashSet set) {
+
+        QueryExpression queryExpression = rangeTable.getQueryExpression();
+        Expression      dataExpression  = rangeTable.getDataExpression();
+
+        if (queryExpression != null) {
+            set = queryExpression.collectRangeVariables(rangeVars, set);
+        }
+
+        if (dataExpression != null) {
+            set = dataExpression.collectRangeVariables(rangeVars, set);
+        }
+
+        return set;
+    }
+
     public OrderedHashSet collectAllExpressions(OrderedHashSet set,
             OrderedIntHashSet typeSet, OrderedIntHashSet stopAtTypeSet) {
 
@@ -852,9 +873,8 @@ public class RangeVariable {
                 rangeGroup, rangeGroups.length, 1);
 
         if (dataExpression != null) {
-            HsqlList unresolved =
-                dataExpression.resolveColumnReferences(session,
-                    RangeGroup.emptyGroup, rangeGroups, null);
+            List unresolved = dataExpression.resolveColumnReferences(session,
+                RangeGroup.emptyGroup, rangeGroups, null);
 
             unresolved = Expression.resolveColumnSet(session,
                     RangeVariable.emptyArray, RangeGroup.emptyArray,
@@ -868,7 +888,7 @@ public class RangeVariable {
         if (queryExpression != null) {
             queryExpression.resolveReferences(session, rangeGroups);
 
-            HsqlList unresolved = queryExpression.getUnresolvedExpressions();
+            List unresolved = queryExpression.getUnresolvedExpressions();
 
             unresolved = Expression.resolveColumnSet(session,
                     RangeVariable.emptyArray, RangeGroup.emptyArray,
