@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,8 +42,8 @@ import org.hsqldb.ParserBase.Recorder;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.jdbc.JDBCResultSet;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HsqlArrayList;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.map.BitMap;
 import org.hsqldb.map.ValuePool;
@@ -59,7 +59,7 @@ import org.hsqldb.types.Types;
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  *
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class Routine implements SchemaObject, RangeGroup, Cloneable {
@@ -112,7 +112,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
     private boolean isLibraryRoutine;
 
     //
-    HashMappedList  parameterList = new HashMappedList();
+    OrderedHashMap  parameterList = new OrderedHashMap();
     RangeVariable[] ranges        = RangeVariable.emptyArray;
 
     //
@@ -386,7 +386,11 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             ? HsqlNameManager.getAutoNoNameColumnString(parameterList.size())
             : name.name;
 
-        parameterList.add(paramName, param);
+        boolean result = parameterList.add(paramName, param);
+
+        if (!result) {
+            throw Error.error(ErrorCode.X_42614);
+        }
     }
 
     public void setLanguage(int lang) {
@@ -1244,7 +1248,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 cl = Class.forName(className);
             } catch (Throwable t) {
                 throw Error.error(t, ErrorCode.X_42501,
-                                  ErrorCode.M_Message_Pair, new Object[] {
+                                  ErrorCode.M_Message_Pair, new String[] {
                     t.toString(), className
                 });
             }
@@ -1254,7 +1258,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             methods = cl.getMethods();
         } catch (Throwable t) {
             throw Error.error(t, ErrorCode.X_42501, ErrorCode.M_Message_Pair,
-                              new Object[] {
+                              new String[] {
                 t.toString(), className
             });
         }
@@ -1415,6 +1419,9 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         return routine;
     }
 
+    /**
+     * simply named function only - requires return type
+     */
     public static void createRoutines(Session session, HsqlName schema,
                                       String name) {
 
@@ -1424,8 +1431,10 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             name, true, SchemaObject.FUNCTION);
 
         for (int i = 0; i < routines.length; i++) {
-            routines[i].setName(routineName);
-            session.database.schemaManager.addSchemaObject(routines[i]);
+            if (routines[i].getReturnType() != Type.SQL_ALL_TYPES) {
+                routines[i].setName(routineName);
+                session.database.schemaManager.addSchemaObject(routines[i]);
+            }
         }
     }
 }
