@@ -75,7 +75,7 @@ import org.hsqldb.types.TypedComparator;
  * Implementation of SQL sessions.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.1
  * @since 1.7.0
  */
 public class Session implements SessionInterface {
@@ -1231,6 +1231,12 @@ public class Session implements SessionInterface {
         for (int i = 0; i < list.size(); i++) {
             Statement cs = (Statement) list.get(i);
 
+            if (isClosed) {
+                result = Result.newErrorResult(Error.error(ErrorCode.X_08503));
+
+                break;
+            }
+
             if (i > 0) {
                 if (cs.getCompileTimestamp()
                         > database.txManager.getSystemChangeNumber()) {
@@ -1354,13 +1360,19 @@ public class Session implements SessionInterface {
                 return handleAbortTransaction();
             }
 
-            boolean interrupted = false;
-
             while (true) {
                 try {
                     latch.await();
                 } catch (InterruptedException e) {
-                    interrupted = txInterruptRollback;
+                    if (txInterruptRollback) {
+                        database.txManager.resetSession(
+                            this, this, Long.MAX_VALUE,
+                            TransactionManager.resetSessionStatement);
+
+                        abortTransaction = true;
+
+                        break;
+                    }
 
                     Thread.interrupted();
 
@@ -1378,13 +1390,9 @@ public class Session implements SessionInterface {
                 break repeatLoop;
             }
 
-            if (abortTransaction || interrupted) {
+            if (abortTransaction) {
                 Result result = handleAbortTransaction();
 
-                if (interrupted) {
-                    Thread.currentThread().interrupt();
-                }
-
                 return result;
             }
 
@@ -1415,6 +1423,16 @@ public class Session implements SessionInterface {
                     try {
                         latch.await();
                     } catch (InterruptedException e) {
+                        if (txInterruptRollback) {
+                            database.txManager.resetSession(
+                                this, this, Long.MAX_VALUE,
+                                TransactionManager.resetSessionStatement);
+
+                            abortTransaction = true;
+
+                            break repeatLoop;
+                        }
+
                         Thread.interrupted();
 
                         continue;
@@ -1802,7 +1820,8 @@ public class Session implements SessionInterface {
     public SimpleDateFormat getSimpleDateFormatGMT() {
 
         if (simpleDateFormatGMT == null) {
-            simpleDateFormatGMT = new SimpleDateFormat("MMMM", Locale.ENGLISH);
+            simpleDateFormatGMT = new SimpleDateFormat("MMMM",
+                    HsqlDateTime.defaultLocale);
 
             simpleDateFormatGMT.setCalendar(getCalendarGMT());
         }
@@ -2308,6 +2327,7 @@ public class Session implements SessionInterface {
 
     // timeouts
     class TimeoutManager {
+
         volatile int  currentTimeout;
         volatile long checkTimestampSCN;
         volatile long checkTimestamp;
