@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,6 +47,7 @@ import org.hsqldb.persist.PersistentStore;
 import org.hsqldb.persist.RowStoreAVLDisk;
 import org.hsqldb.persist.ScriptLoader;
 import org.hsqldb.persist.TableSpaceManager;
+import org.hsqldb.persist.TextFileOps;
 import org.hsqldb.result.Result;
 import org.hsqldb.result.ResultMetaData;
 import org.hsqldb.rights.User;
@@ -59,7 +60,7 @@ import org.hsqldb.types.Type;
  * Implementation of Statement for SQL commands.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class StatementCommand extends Statement {
@@ -117,6 +118,8 @@ public class StatementCommand extends Statement {
 
                 break;
             }
+            case StatementTypes.UNLOAD_DATA :
+            case StatementTypes.LOAD_DATA :
             case StatementTypes.LOAD_SCRIPT : {
                 group    = StatementTypes.X_HSQLDB_DATABASE_OPERATION;
                 isLogged = false;
@@ -379,10 +382,8 @@ public class StatementCommand extends Statement {
                     session.checkDDLWrite();
 
                     if (check) {
-                        value =
-                            session.database.getProperties()
-                                .getPropertyWithinRange(HsqlDatabaseProperties
-                                    .hsqldb_cache_rows, value);
+                        value = HsqlDatabaseProperties.getPropertyWithinRange(
+                            HsqlDatabaseProperties.hsqldb_cache_rows, value);
                     }
 
                     session.database.logger.setCacheMaxRows(value);
@@ -401,10 +402,8 @@ public class StatementCommand extends Statement {
                     session.checkDDLWrite();
 
                     if (check) {
-                        value =
-                            session.database.getProperties()
-                                .getPropertyWithinRange(HsqlDatabaseProperties
-                                    .hsqldb_cache_size, value);
+                        value = HsqlDatabaseProperties.getPropertyWithinRange(
+                            HsqlDatabaseProperties.hsqldb_cache_size, value);
                     }
 
                     session.database.logger.setCacheSize(value);
@@ -424,13 +423,13 @@ public class StatementCommand extends Statement {
 
                     if (session.isProcessingScript()) {
                         session.database.logger.setFilesTimestamp(value1);
-                        session.database.txManager.setGlobalChangeTimestamp(
+                        session.database.txManager.setSystemChangeNumber(
                             value1 + 1);
                     } else if (session.isProcessingLog()) {
                         if (value2 > 0) {
                             session.database.logger.setFilesTimestamp(value1);
                             session.database.txManager
-                                .setGlobalChangeTimestamp(value1 + 1);
+                                .setSystemChangeNumber(value1 + 1);
                         }
                     }
 
@@ -530,7 +529,7 @@ public class StatementCommand extends Statement {
                     session.checkAdmin();
                     session.checkDDLWrite();
 
-                    if (!session.database.getProperties().validateProperty(
+                    if (!HsqlDatabaseProperties.validateProperty(
                             HsqlDatabaseProperties.hsqldb_defrag_limit,
                             value)) {
                         throw Error.error(ErrorCode.X_42556);
@@ -545,12 +544,19 @@ public class StatementCommand extends Statement {
             }
             case StatementTypes.SET_DATABASE_FILES_EVENT_LOG : {
                 try {
-                    int     value = ((Integer) arguments[0]).intValue();
-                    boolean isSql = ((Boolean) arguments[1]).booleanValue();
+                    int     value    = ((Integer) arguments[0]).intValue();
+                    boolean isSql    = ((Boolean) arguments[1]).booleanValue();
+                    boolean internal = ((Boolean) arguments[2]).booleanValue();
 
                     session.checkAdmin();
                     session.checkDDLWrite();
-                    session.database.logger.setEventLogLevel(value, isSql);
+
+                    if (internal) {
+                        session.database.logger.setEventLogLevel(value, isSql);
+                    } else {
+                        session.database.logger.setExternalEventLogLevel(
+                            value);
+                    }
 
                     return Result.updateZeroResult;
                 } catch (HsqlException e) {
@@ -572,6 +578,9 @@ public class StatementCommand extends Statement {
                     } else {
                         int value = ((Integer) arguments[0]).intValue();
 
+                        value = HsqlDatabaseProperties.getPropertyWithinRange(
+                            HsqlDatabaseProperties.hsqldb_nio_max_size, value);
+
                         session.database.logger.setNioMaxSize(value);
                     }
 
@@ -599,6 +608,10 @@ public class StatementCommand extends Statement {
 
                     session.checkAdmin();
                     session.checkDDLWrite();
+
+                    value = HsqlDatabaseProperties.getPropertyWithinRange(
+                        HsqlDatabaseProperties.hsqldb_log_size, value);
+
                     session.database.logger.setLogSize(value);
 
                     return Result.updateZeroResult;
@@ -636,6 +649,10 @@ public class StatementCommand extends Statement {
                 try {
                     int value = ((Integer) arguments[0]).intValue();
 
+                    value = HsqlDatabaseProperties.getPropertyWithinRange(
+                        HsqlDatabaseProperties.hsqldb_write_delay_millis,
+                        value);
+
                     session.checkAdmin();
                     session.checkDDLWrite();
                     session.database.logger.setWriteDelay(value);
@@ -772,9 +789,21 @@ public class StatementCommand extends Statement {
                 } else if (HsqlDatabaseProperties.sql_convert_trunc.equals(
                         property)) {
                     session.database.setConvertTrunc(mode);
+                } else if (HsqlDatabaseProperties.sql_trunc_trailing.equals(
+                        property)) {
+                    session.database.setTruncateTrailing(mode);
                 } else if (HsqlDatabaseProperties.sql_avg_scale.equals(
                         property)) {
+                    value = HsqlDatabaseProperties.getPropertyWithinRange(
+                        HsqlDatabaseProperties.sql_avg_scale, value);
+
                     session.database.setAvgScale(value);
+                } else if (HsqlDatabaseProperties.sql_max_recursive.equals(
+                        property)) {
+                    value = HsqlDatabaseProperties.getPropertyWithinRange(
+                        HsqlDatabaseProperties.sql_max_recursive, value);
+
+                    session.database.setMaxRecursive(value);
                 } else if (HsqlDatabaseProperties.sql_double_nan.equals(
                         property)) {
                     session.database.setDoubleNaN(mode);
@@ -919,6 +948,11 @@ public class StatementCommand extends Statement {
                 int size = ((Integer) arguments[0]).intValue();
 
                 session.checkAdmin();
+
+                size = HsqlDatabaseProperties.getPropertyWithinRange(
+                    HsqlDatabaseProperties.hsqldb_result_max_memory_rows,
+                    size);
+
                 session.database.setResultMaxMemoryRows(size);
 
                 return Result.updateZeroResult;
@@ -1049,6 +1083,55 @@ public class StatementCommand extends Statement {
                     return Result.newErrorResult(e, sql);
                 }
             }
+            case StatementTypes.LOAD_DATA : {
+                try {
+                    HsqlName tableName = (HsqlName) arguments[0];
+                    String   textprops = (String) arguments[1];
+                    int      mode      = ((Integer) arguments[2]).intValue();
+                    Table table =
+                        session.database.schemaManager.findTable(session,
+                            tableName.name, tableName.schema.name, null);
+
+                    if (table == null) {
+                        throw Error.error(
+                            ErrorCode.X_42501,
+                            tableName.getSchemaQualifiedStatementName());
+                    }
+
+                    if (!session.getGrantee().canPerformScriptOps()) {
+                        throw Error.error(ErrorCode.X_42507);
+                    }
+
+                    return TextFileOps.loadTextData(session, textprops, table,
+                                                    mode);
+                } catch (HsqlException e) {
+                    return Result.newErrorResult(e, sql);
+                }
+            }
+            case StatementTypes.UNLOAD_DATA : {
+                try {
+                    HsqlName tableName = (HsqlName) arguments[0];
+                    String   textprops = (String) arguments[1];
+                    Table table =
+                        session.database.schemaManager.findTable(session,
+                            tableName.name, tableName.schema.name, null);
+
+                    if (table == null) {
+                        throw Error.error(
+                            ErrorCode.X_42501,
+                            tableName.getSchemaQualifiedStatementName());
+                    }
+
+                    if (!session.getGrantee().canPerformScriptOps()) {
+                        throw Error.error(ErrorCode.X_42507);
+                    }
+
+                    return TextFileOps.unloadTextData(session, textprops,
+                                                      table);
+                } catch (HsqlException e) {
+                    return Result.newErrorResult(e, sql);
+                }
+            }
             case StatementTypes.CHECK_INDEX : {
                 try {
                     HsqlName tableName = (HsqlName) arguments[0];
@@ -1273,7 +1356,7 @@ public class StatementCommand extends Statement {
                     return Result.updateZeroResult;
                 } catch (Throwable e) {
                     if (!(e instanceof HsqlException)) {
-                        e = Error.error(ErrorCode.GENERAL_IO_ERROR,
+                        e = Error.error(e, ErrorCode.GENERAL_IO_ERROR,
                                         e.toString());
                     }
 
@@ -1310,13 +1393,12 @@ public class StatementCommand extends Statement {
                             table.getSchemaName());
 
                     TableWorks tw     = new TableWorks(session, table);
-                    boolean    result = tw.setTableType(session, type);
+                    boolean    result = tw.setTableType(type);
 
                     if (!result) {
                         throw Error.error(ErrorCode.GENERAL_IO_ERROR);
                     }
 
-                    oldStore.removeAll();
                     session.database.schemaManager.setSchemaChangeTimestamp();
 
                     if (name.schema == SqlInvariants.LOBS_SCHEMA_HSQLNAME) {
@@ -1440,7 +1522,7 @@ public class StatementCommand extends Statement {
 
                             session.database.txManager.resetSession(session,
                                     targetSession,
-                                    targetSession.statementStartTimestamp,
+                                    targetSession.statementStartSCN,
                                     TransactionManager.resetSessionStatement);
                             break;
                     }
