@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import org.hsqldb.types.Type;
  * Implementation of Statement for updating result rows.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.2
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class StatementResultUpdate extends StatementDML {
@@ -87,6 +87,7 @@ public class StatementResultUpdate extends StatementDML {
 
     Result getResult(Session session) {
 
+        session.getTransactionUTC();
         checkAccessRights(session);
 
         Object[]        args = session.sessionContext.dynamicArguments;
@@ -98,7 +99,7 @@ public class StatementResultUpdate extends StatementDML {
             case ResultConstants.UPDATE_CURSOR : {
                 row = getRow(session, args);
 
-                /**
+                /*
                  * @todo - in 2PL mode isDeleted() always returns false.
                  * While write lock prevents delete by other transactions,
                  * same-transaction deletes are not caught
@@ -143,7 +144,7 @@ public class StatementResultUpdate extends StatementDML {
 
                 list.addRow(row);
                 list.endMainDataSet();
-                delete(session, baseTable, list);
+                delete(session, baseTable, list, null);
 
                 break;
             }
