@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,8 @@
 
 package org.hsqldb;
 
+import java.util.TimeZone;
+
 import org.hsqldb.HsqlNameManager.HsqlName;
 import org.hsqldb.ParserDQL.CompileContext;
 import org.hsqldb.error.Error;
@@ -40,6 +42,7 @@ import org.hsqldb.lib.List;
 import org.hsqldb.result.Result;
 import org.hsqldb.rights.Grantee;
 import org.hsqldb.rights.User;
+import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.DTIType;
 import org.hsqldb.types.IntervalSecondData;
 import org.hsqldb.types.Type;
@@ -49,7 +52,7 @@ import org.hsqldb.types.Types;
  * Implementation of Statement for SQL session statements.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class StatementSession extends Statement {
@@ -106,12 +109,9 @@ public class StatementSession extends Statement {
                     e.setDataType(session, Type.SQL_INTERVAL_HOUR_TO_MINUTE);
                 }
 
-                if (e.dataType.isCharacterType()) {
-                    e = new ExpressionOp(e, Type.SQL_INTERVAL_HOUR_TO_MINUTE);
-                    expressions[0] = e;
-                }
-
-                if (e.dataType.typeCode != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
+                if (e.dataType.isCharacterType()) {}
+                else if (e.dataType.typeCode
+                         != Types.SQL_INTERVAL_HOUR_TO_MINUTE) {
                     throw Error.error(ErrorCode.X_42563);
                 }
 
@@ -443,7 +443,7 @@ public class StatementSession extends Statement {
                 if (expressions[0].getType() == OpTypes.VALUE
                         && expressions[0].getConstantValueNoCheck(session)
                            == null) {
-                    session.setZoneSeconds(session.sessionTimeZoneSeconds);
+                    session.resetTimeZone();
 
                     return Result.updateZeroResult;
                 }
@@ -485,13 +485,40 @@ public class StatementSession extends Statement {
                     }
                 }
 
-                long seconds = ((IntervalSecondData) value).getSeconds();
+                if (value instanceof String) {
+                    String zoneString = (String) value;
 
-                if (-DTIType.timezoneSecondsLimit <= seconds
-                        && seconds <= DTIType.timezoneSecondsLimit) {
-                    session.setZoneSeconds((int) seconds);
+                    if (DateTimeType.zoneIDs.contains(zoneString)) {
+                        TimeZone zone = TimeZone.getTimeZone(zoneString);
 
-                    return Result.updateZeroResult;
+                        session.setTimeZone(zone);
+
+                        return Result.updateZeroResult;
+                    } else {
+                        value =
+                            Type.SQL_INTERVAL_HOUR_TO_MINUTE
+                                .convertToDefaultType(session, value);
+                    }
+                }
+
+                if (value instanceof IntervalSecondData) {
+                    IntervalSecondData interval = (IntervalSecondData) value;
+                    long               seconds  = interval.getSeconds();
+
+                    if (-DTIType.timezoneSecondsLimit <= seconds
+                            && seconds <= DTIType.timezoneSecondsLimit) {
+                        String i =
+                            Type.SQL_INTERVAL_HOUR_TO_MINUTE.convertToString(
+                                interval);
+                        String   sign       = seconds < 0 ? ""
+                                                          : "+";
+                        String   zoneString = "GMT" + sign + i;
+                        TimeZone zone       = TimeZone.getTimeZone(zoneString);
+
+                        session.setTimeZone(zone);
+
+                        return Result.updateZeroResult;
+                    }
                 }
 
                 return Result.newErrorResult(Error.error(ErrorCode.X_22009),
@@ -677,9 +704,14 @@ public class StatementSession extends Statement {
             //
             case StatementTypes.SET_SESSION_AUTOCOMMIT : {
                 boolean mode = ((Boolean) arguments[0]).booleanValue();
+                int     rows = ((Integer) arguments[1]).intValue();
 
                 try {
-                    session.setAutoCommit(mode);
+                    if (rows < 0) {
+                        session.setAutoCommit(mode);
+                    } else {
+                        session.setAutoCommitRows(rows);
+                    }
 
                     return Result.updateZeroResult;
                 } catch (HsqlException e) {
