@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,15 +41,15 @@ import org.hsqldb.persist.PersistentStore;
  * Manages rows involved in transactions
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.0
  * @since 2.0.0
  */
 public class TransactionManagerMV2PL extends TransactionManagerCommon
 implements TransactionManager {
 
     // functional unit - merged committed transactions
-    HsqlDeque committedTransactions          = new HsqlDeque();
-    LongDeque committedTransactionTimestamps = new LongDeque();
+    HsqlDeque committedTransactions    = new HsqlDeque();
+    LongDeque committedTransactionSCNs = new LongDeque();
 
     public TransactionManagerMV2PL(Database db) {
 
@@ -59,12 +59,12 @@ implements TransactionManager {
         txModel    = MVLOCKS;
     }
 
-    public long getGlobalChangeTimestamp() {
-        return globalChangeTimestamp.get();
+    public long getSystemChangeNumber() {
+        return systemChangeNumber.get();
     }
 
-    public void setGlobalChangeTimestamp(long ts) {
-        globalChangeTimestamp.set(ts);
+    public void setSystemChangeNumber(long ts) {
+        systemChangeNumber.set(ts);
     }
 
     public boolean isMVRows() {
@@ -98,7 +98,7 @@ implements TransactionManager {
         try {
             int limit = session.rowActionList.size();
 
-            session.actionTimestamp = getNextGlobalChangeTimestamp();
+            session.actionSCN = getNextSystemChangeNumber();
 
             for (int i = 0; i < limit; i++) {
                 RowAction action = (RowAction) session.rowActionList.get(i);
@@ -124,8 +124,8 @@ implements TransactionManager {
             int limit = session.rowActionList.size();
 
             // new actionTimestamp used for commitTimestamp
-            session.actionTimestamp         = getNextGlobalChangeTimestamp();
-            session.transactionEndTimestamp = session.actionTimestamp;
+            session.actionSCN         = getNextSystemChangeNumber();
+            session.transactionEndSCN = session.actionSCN;
 
             endTransaction(session);
 
@@ -143,8 +143,7 @@ implements TransactionManager {
             if (newLimit > limit) {
                 Object[] list = session.rowActionList.getArray();
 
-                mergeTransaction(list, limit, newLimit,
-                                 session.actionTimestamp);
+                mergeTransaction(list, limit, newLimit, session.actionSCN);
                 finaliseRows(session, list, limit, newLimit);
                 session.rowActionList.setSize(limit);
             }
@@ -152,10 +151,10 @@ implements TransactionManager {
             // session.actionTimestamp is the committed tx timestamp
             if (session == lobSession
                     || getFirstLiveTransactionTimestamp()
-                       > session.actionTimestamp) {
+                       > session.actionSCN) {
                 Object[] list = session.rowActionList.getArray();
 
-                mergeTransaction(list, 0, limit, session.actionTimestamp);
+                mergeTransaction(list, 0, limit, session.actionSCN);
                 finaliseRows(session, list, 0, limit);
             } else {
                 Object[] list = session.rowActionList.toArray();
@@ -179,11 +178,11 @@ implements TransactionManager {
         writeLock.lock();
 
         try {
-            session.abortTransaction        = false;
-            session.actionTimestamp         = getNextGlobalChangeTimestamp();
-            session.transactionEndTimestamp = session.actionTimestamp;
+            session.abortTransaction  = false;
+            session.actionSCN         = getNextSystemChangeNumber();
+            session.transactionEndSCN = session.actionSCN;
 
-            rollbackPartial(session, 0, session.transactionTimestamp);
+            rollbackPartial(session, 0, session.transactionSCN);
             endTransaction(session);
             session.logSequences();
 
@@ -211,9 +210,7 @@ implements TransactionManager {
     }
 
     public void rollbackAction(Session session) {
-
-        rollbackPartial(session, session.actionIndex,
-                        session.actionStartTimestamp);
+        rollbackPartial(session, session.actionIndex, session.actionStartSCN);
         endActionTPL(session);
     }
 
@@ -341,13 +338,13 @@ implements TransactionManager {
      */
     void addToCommittedQueue(Session session, Object[] list) {
 
-        synchronized (committedTransactionTimestamps) {
+        synchronized (committedTransactionSCNs) {
 
             // add the txList according to commit timestamp
             committedTransactions.addLast(list);
 
             // get session commit timestamp
-            committedTransactionTimestamps.addLast(session.actionTimestamp);
+            committedTransactionSCNs.addLast(session.actionSCN);
 /* debug 190
             if (committedTransactions.size() > 64) {
                 System.out.println("******* excessive transaction queue");
@@ -367,15 +364,15 @@ implements TransactionManager {
             long     commitTimestamp = 0;
             Object[] actions         = null;
 
-            synchronized (committedTransactionTimestamps) {
-                if (committedTransactionTimestamps.isEmpty()) {
+            synchronized (committedTransactionSCNs) {
+                if (committedTransactionSCNs.isEmpty()) {
                     break;
                 }
 
-                commitTimestamp = committedTransactionTimestamps.getFirst();
+                commitTimestamp = committedTransactionSCNs.getFirst();
 
                 if (commitTimestamp < timestamp) {
-                    committedTransactionTimestamps.removeFirst();
+                    committedTransactionSCNs.removeFirst();
 
                     actions = (Object[]) committedTransactions.removeFirst();
                 } else {
@@ -395,8 +392,7 @@ implements TransactionManager {
         try {
             if (!session.isTransaction) {
                 beginTransactionCommon(session);
-                liveTransactionTimestamps.addLast(
-                    session.transactionTimestamp);
+                liveTransactionSCNs.addLast(session.transactionSCN);
             }
         } finally {
             writeLock.unlock();
@@ -454,12 +450,11 @@ implements TransactionManager {
 
         try {
             if (session.isTransaction) {
-                session.actionTimestamp      = getNextGlobalChangeTimestamp();
-                session.actionStartTimestamp = session.actionTimestamp;
+                session.actionSCN      = getNextSystemChangeNumber();
+                session.actionStartSCN = session.actionSCN;
             } else {
                 beginTransactionCommon(session);
-                liveTransactionTimestamps.addLast(
-                    session.transactionTimestamp);
+                liveTransactionSCNs.addLast(session.transactionSCN);
             }
         } finally {
             writeLock.unlock();
@@ -479,12 +474,12 @@ implements TransactionManager {
      */
     private void endTransaction(Session session) {
 
-        long timestamp = session.transactionTimestamp;
-        int  index     = liveTransactionTimestamps.indexOf(timestamp);
+        long timestamp = session.transactionSCN;
+        int  index     = liveTransactionSCNs.indexOf(timestamp);
 
         if (index >= 0) {
             transactionCount.decrementAndGet();
-            liveTransactionTimestamps.remove(index);
+            liveTransactionSCNs.remove(index);
             mergeExpiredTransactions(session);
         }
     }
