@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ import org.hsqldb.persist.PersistentStore;
  * DatabaseInformation implementations. <p>
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.0
  * @since 1.7.2
  */
 public class DatabaseInformation {
@@ -71,103 +71,104 @@ public class DatabaseInformation {
     static final int SYSTEM_TABLES            = 8;
     static final int SYSTEM_TABLETYPES        = 9;
     static final int SYSTEM_TYPEINFO          = 10;
-    static final int SYSTEM_UDTS              = 11;
-    static final int SYSTEM_USERS             = 12;    //-- ref in SqlFile only
-    static final int SYSTEM_VERSIONCOLUMNS    = 13;    //-- returns autogenerated columns
-    static final int SYSTEM_SEQUENCES = 14;            //-- same as SEQUENCES
+    static final int SYSTEM_UDTATTRIBUTES     = 11;
+    static final int SYSTEM_UDTS              = 12;
+    static final int SYSTEM_USERS             = 13;    //-- ref in SqlFile only
+    static final int SYSTEM_VERSIONCOLUMNS    = 14;    //-- returns autogenerated columns
+    static final int SYSTEM_SEQUENCES = 15;            //-- same as SEQUENCES
 
     // HSQLDB-specific
-    static final int SYSTEM_CACHEINFO             = 15;
-    static final int SYSTEM_COLUMN_SEQUENCE_USAGE = 16;
-    static final int SYSTEM_COMMENTS              = 17;
-    static final int SYSTEM_CONNECTION_PROPERTIES = 18;
-    static final int SYSTEM_INDEXSTATS            = 19;
-    static final int SYSTEM_KEY_INDEX_USAGE       = 20;
-    static final int SYSTEM_PROPERTIES            = 21;
-    static final int SYSTEM_SESSIONINFO           = 22;
-    static final int SYSTEM_SESSIONS              = 23;
-    static final int SYSTEM_TABLESTATS            = 24;
-    static final int SYSTEM_TEXTTABLES            = 25;
-    static final int SYSTEM_SYNONYMS              = 26;
+    static final int SYSTEM_CACHEINFO             = 16;
+    static final int SYSTEM_COLUMN_SEQUENCE_USAGE = 17;
+    static final int SYSTEM_COMMENTS              = 18;
+    static final int SYSTEM_CONNECTION_PROPERTIES = 19;
+    static final int SYSTEM_INDEXSTATS            = 20;
+    static final int SYSTEM_KEY_INDEX_USAGE       = 21;
+    static final int SYSTEM_PROPERTIES            = 22;
+    static final int SYSTEM_SESSIONINFO           = 23;
+    static final int SYSTEM_SESSIONS              = 24;
+    static final int SYSTEM_TABLESTATS            = 25;
+    static final int SYSTEM_TEXTTABLES            = 26;
+    static final int SYSTEM_SYNONYMS              = 27;
 
     // SQL 200n tables
-    static final int ADMINISTRABLE_ROLE_AUTHORIZATIONS = 27;
-    static final int APPLICABLE_ROLES                  = 28;
-    static final int ASSERTIONS                        = 29;
-    static final int AUTHORIZATIONS                    = 30;
-    static final int CHARACTER_SETS                    = 31;
-    static final int CHECK_CONSTRAINT_ROUTINE_USAGE    = 32;
-    static final int CHECK_CONSTRAINTS                 = 33;
-    static final int COLLATIONS                        = 34;
-    static final int COLUMN_COLUMN_USAGE               = 35;
-    static final int COLUMN_DOMAIN_USAGE               = 36;
-    static final int COLUMN_PRIVILEGES                 = 37;
-    static final int COLUMN_UDT_USAGE                  = 38;
-    static final int COLUMNS                           = 39;
-    static final int CONSTRAINT_COLUMN_USAGE           = 40;
-    static final int CONSTRAINT_PERIOD_USAGE           = 41;
-    static final int CONSTRAINT_TABLE_USAGE            = 42;
-    static final int DATA_TYPE_PRIVILEGES              = 43;
-    static final int DOMAIN_CONSTRAINTS                = 44;
-    static final int DOMAINS                           = 45;
-    static final int ELEMENT_TYPES                     = 46;
-    static final int ENABLED_ROLES                     = 47;
-    static final int INFORMATION_SCHEMA_CATALOG_NAME   = 48;
-    static final int JAR_JAR_USAGE                     = 49;
-    static final int JARS                              = 50;
-    static final int KEY_COLUMN_USAGE                  = 51;
-    static final int KEY_PERIOD_USAGE                  = 52;
-    static final int METHOD_SPECIFICATIONS             = 53;
-    static final int MODULE_COLUMN_USAGE               = 54;
-    static final int MODULE_PRIVILEGES                 = 55;
-    static final int MODULE_TABLE_USAGE                = 56;
-    static final int MODULES                           = 57;
-    static final int PARAMETERS                        = 58;
-    static final int PERIODS                           = 59;
-    static final int REFERENTIAL_CONSTRAINTS           = 60;
-    static final int ROLE_AUTHORIZATION_DESCRIPTORS    = 61;
-    static final int ROLE_COLUMN_GRANTS                = 62;
-    static final int ROLE_MODULE_GRANTS                = 63;
-    static final int ROLE_ROUTINE_GRANTS               = 64;
-    static final int ROLE_TABLE_GRANTS                 = 65;
-    static final int ROLE_UDT_GRANTS                   = 66;
-    static final int ROLE_USAGE_GRANTS                 = 67;
-    static final int ROUTINE_COLUMN_USAGE              = 68;
-    static final int ROUTINE_JAR_USAGE                 = 69;
-    static final int ROUTINE_PERIOD_USAGE              = 70;
-    static final int ROUTINE_PRIVILEGES                = 71;
-    static final int ROUTINE_ROUTINE_USAGE             = 72;
-    static final int ROUTINE_SEQUENCE_USAGE            = 73;
-    static final int ROUTINE_TABLE_USAGE               = 74;
-    static final int ROUTINES                          = 75;
-    static final int SCHEMATA                          = 76;
-    static final int SEQUENCES                         = 77;
-    static final int SQL_FEATURES                      = 78;
-    static final int SQL_IMPLEMENTATION_INFO           = 79;
-    static final int SQL_PACKAGES                      = 80;
-    static final int SQL_PARTS                         = 81;
-    static final int SQL_SIZING                        = 82;
-    static final int SQL_SIZING_PROFILES               = 83;
-    static final int TABLE_CONSTRAINTS                 = 84;
-    static final int TABLE_PRIVILEGES                  = 85;
-    static final int TABLES                            = 86;
-    static final int TRANSLATIONS                      = 87;
-    static final int TRIGGER_COLUMN_USAGE              = 88;
-    static final int TRIGGER_PERIOD_USAGE              = 89;
-    static final int TRIGGER_ROUTINE_USAGE             = 90;
-    static final int TRIGGER_SEQUENCE_USAGE            = 91;
-    static final int TRIGGER_TABLE_USAGE               = 92;
-    static final int TRIGGERED_UPDATE_COLUMNS          = 93;
-    static final int TRIGGERS                          = 94;
-    static final int TYPE_JAR_USAGE                    = 95;
-    static final int UDT_PRIVILEGES                    = 96;
-    static final int USAGE_PRIVILEGES                  = 97;
-    static final int USER_DEFINED_TYPES                = 98;
-    static final int VIEW_COLUMN_USAGE                 = 99;
-    static final int VIEW_PERIOD_USAGE                 = 100;
-    static final int VIEW_ROUTINE_USAGE                = 101;
-    static final int VIEW_TABLE_USAGE                  = 102;
-    static final int VIEWS                             = 103;
+    static final int ADMINISTRABLE_ROLE_AUTHORIZATIONS = 28;
+    static final int APPLICABLE_ROLES                  = 29;
+    static final int ASSERTIONS                        = 30;
+    static final int AUTHORIZATIONS                    = 31;
+    static final int CHARACTER_SETS                    = 32;
+    static final int CHECK_CONSTRAINT_ROUTINE_USAGE    = 33;
+    static final int CHECK_CONSTRAINTS                 = 34;
+    static final int COLLATIONS                        = 35;
+    static final int COLUMN_COLUMN_USAGE               = 36;
+    static final int COLUMN_DOMAIN_USAGE               = 37;
+    static final int COLUMN_PRIVILEGES                 = 38;
+    static final int COLUMN_UDT_USAGE                  = 39;
+    static final int COLUMNS                           = 40;
+    static final int CONSTRAINT_COLUMN_USAGE           = 41;
+    static final int CONSTRAINT_PERIOD_USAGE           = 42;
+    static final int CONSTRAINT_TABLE_USAGE            = 43;
+    static final int DATA_TYPE_PRIVILEGES              = 44;
+    static final int DOMAIN_CONSTRAINTS                = 45;
+    static final int DOMAINS                           = 46;
+    static final int ELEMENT_TYPES                     = 47;
+    static final int ENABLED_ROLES                     = 48;
+    static final int INFORMATION_SCHEMA_CATALOG_NAME   = 49;
+    static final int JAR_JAR_USAGE                     = 50;
+    static final int JARS                              = 51;
+    static final int KEY_COLUMN_USAGE                  = 52;
+    static final int KEY_PERIOD_USAGE                  = 53;
+    static final int METHOD_SPECIFICATIONS             = 54;
+    static final int MODULE_COLUMN_USAGE               = 55;
+    static final int MODULE_PRIVILEGES                 = 56;
+    static final int MODULE_TABLE_USAGE                = 57;
+    static final int MODULES                           = 58;
+    static final int PARAMETERS                        = 59;
+    static final int PERIODS                           = 60;
+    static final int REFERENTIAL_CONSTRAINTS           = 61;
+    static final int ROLE_AUTHORIZATION_DESCRIPTORS    = 62;
+    static final int ROLE_COLUMN_GRANTS                = 63;
+    static final int ROLE_MODULE_GRANTS                = 64;
+    static final int ROLE_ROUTINE_GRANTS               = 65;
+    static final int ROLE_TABLE_GRANTS                 = 66;
+    static final int ROLE_UDT_GRANTS                   = 67;
+    static final int ROLE_USAGE_GRANTS                 = 68;
+    static final int ROUTINE_COLUMN_USAGE              = 69;
+    static final int ROUTINE_JAR_USAGE                 = 70;
+    static final int ROUTINE_PERIOD_USAGE              = 71;
+    static final int ROUTINE_PRIVILEGES                = 72;
+    static final int ROUTINE_ROUTINE_USAGE             = 73;
+    static final int ROUTINE_SEQUENCE_USAGE            = 74;
+    static final int ROUTINE_TABLE_USAGE               = 75;
+    static final int ROUTINES                          = 76;
+    static final int SCHEMATA                          = 77;
+    static final int SEQUENCES                         = 78;
+    static final int SQL_FEATURES                      = 79;
+    static final int SQL_IMPLEMENTATION_INFO           = 80;
+    static final int SQL_PACKAGES                      = 81;
+    static final int SQL_PARTS                         = 82;
+    static final int SQL_SIZING                        = 83;
+    static final int SQL_SIZING_PROFILES               = 84;
+    static final int TABLE_CONSTRAINTS                 = 85;
+    static final int TABLE_PRIVILEGES                  = 86;
+    static final int TABLES                            = 87;
+    static final int TRANSLATIONS                      = 88;
+    static final int TRIGGER_COLUMN_USAGE              = 89;
+    static final int TRIGGER_PERIOD_USAGE              = 90;
+    static final int TRIGGER_ROUTINE_USAGE             = 91;
+    static final int TRIGGER_SEQUENCE_USAGE            = 92;
+    static final int TRIGGER_TABLE_USAGE               = 93;
+    static final int TRIGGERED_UPDATE_COLUMNS          = 94;
+    static final int TRIGGERS                          = 95;
+    static final int TYPE_JAR_USAGE                    = 96;
+    static final int UDT_PRIVILEGES                    = 97;
+    static final int USAGE_PRIVILEGES                  = 98;
+    static final int USER_DEFINED_TYPES                = 99;
+    static final int VIEW_COLUMN_USAGE                 = 100;
+    static final int VIEW_PERIOD_USAGE                 = 101;
+    static final int VIEW_ROUTINE_USAGE                = 102;
+    static final int VIEW_TABLE_USAGE                  = 103;
+    static final int VIEWS                             = 104;
 
     /** system table names strictly in order of their ids */
     static final String[] sysTableNames = {
@@ -182,6 +183,7 @@ public class DatabaseInformation {
         "SYSTEM_TABLES",                                         //
         "SYSTEM_TABLETYPES",                                     //
         "SYSTEM_TYPEINFO",                                       //
+        "SYSTEM_UDTATTRIBUTES",                                           //
         "SYSTEM_UDTS",                                           //
         "SYSTEM_USERS",                                          //
         "SYSTEM_VERSIONCOLUMNS",                                 //
@@ -281,7 +283,7 @@ public class DatabaseInformation {
         "VIEWS",                                                 //
     };
 
-    /** Map: table name => table id */
+    /** Map: table name : table id */
     static final IntValueHashMap sysTableNamesMap;
 
     static {
