@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,7 +42,7 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.FrameworkLogger;
 import org.hsqldb.lib.java.JavaSystem;
 
-/* $Id: JDBCClob.java 6266 2021-01-25 16:08:06Z fredt $ */
+/* $Id: JDBCClob.java 6572 2022-07-07 17:32:55Z fredt $ */
 
 // campbell-burnet@users 2004-03/04-xx - doc 1.7.2 - javadocs updated; methods put in
 //                                            correct (historical, interface
@@ -124,9 +124,6 @@ import org.hsqldb.lib.java.JavaSystem;
  */
 public class JDBCClob implements Clob {
 
-    private static final FrameworkLogger LOG =
-        FrameworkLogger.getLog(JDBCClob.class);
-
     /**
      * Retrieves the number of characters
      * in the <code>CLOB</code> value
@@ -364,7 +361,7 @@ public class JDBCClob implements Clob {
      * value will be increased to accommodate the extra characters.
      * <p>
      * <b>Note:</b> If the value specified for <code>pos</code>
-     * is greater then the length+1 of the <code>CLOB</code> value then the
+     * is greater than the length+1 of the <code>CLOB</code> value then the
      * behavior is undefined. Some JDBC drivers may throw a
      * <code>SQLException</code> while other drivers may support this
      * operation.
@@ -435,7 +432,7 @@ public class JDBCClob implements Clob {
      * value will be increased to accommodate the extra characters.
      * <p>
      * <b>Note:</b> If the value specified for <code>pos</code>
-     * is greater then the length+1 of the <code>CLOB</code> value then the
+     * is greater than the length+1 of the <code>CLOB</code> value then the
      * behavior is undefined. Some JDBC drivers may throw a
      * <code>SQLException</code> while other drivers may support this
      * operation.
@@ -685,7 +682,7 @@ public class JDBCClob implements Clob {
      * value will be increased to accommodate the extra characters.
      * <p>
      * <b>Note:</b> If the value specified for <code>pos</code>
-     * is greater then the length+1 of the <code>CLOB</code> value then the
+     * is greater than the length+1 of the <code>CLOB</code> value then the
      * behavior is undefined. Some JDBC drivers may throw a
      * <code>SQLException</code> while other drivers may support this
      * operation.
@@ -844,7 +841,7 @@ public class JDBCClob implements Clob {
     //------------------------- JDBC 4.0 -----------------------------------
 
     /**
-     * This method frees the <code>Clob</code> object and releases the resources the resources
+     * This method frees the <code>Clob</code> object and releases the resources
      * that it holds.  The object is invalid once the <code>free</code> method
      * is called.
      * <p>
