@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ import org.hsqldb.result.Result;
 import org.hsqldb.result.ResultConstants;
 import org.hsqldb.result.ResultProperties;
 
-/* $Id: JDBCStatement.java 6294 2021-02-07 18:08:27Z fredt $ */
+/* $Id: JDBCStatement.java 6489 2022-04-19 18:00:13Z fredt $ */
 
 // fredt@users   20020320 - patch 1.7.0 - JDBC 2 support and error trapping
 //
@@ -103,7 +103,7 @@ import org.hsqldb.result.ResultProperties;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.0
+ * @version 2.7.0
  * @since HSQLDB 1.9.0
  * @see JDBCConnection#createStatement
  * @see JDBCResultSet
@@ -547,7 +547,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      * used in SQL positioned update or delete statements to identify the
      * current row in the <code>ResultSet</code> object generated by this
      * statement.  If the database does not support positioned update/delete,
-     * this method is a noop.  To insure that a cursor has the proper isolation
+     * this method is a noop.  To ensure that a cursor has the proper isolation
      * level to support updates, the cursor's <code>SELECT</code> statement
      * should have the form <code>SELECT FOR UPDATE</code>.  If
      * <code>FOR UPDATE</code> is not present, positioned updates may fail.
@@ -1586,10 +1586,9 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      * Retrieves whether this <code>Statement</code> object has been closed. A <code>Statement</code> is closed if the
      * method close has been called on it, or if it is automatically closed.
      * @return true if this <code>Statement</code> object is closed; false if it is still open
-     * @throws SQLException if a database access error occurs
      * @since JDK 1.6, HSQLDB 2.0
      */
-    public synchronized boolean isClosed() throws SQLException {
+    public synchronized boolean isClosed() {
         return isClosed;
     }
 
@@ -1657,7 +1656,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      * or a proxy for the receiver. If the receiver is a wrapper
      * and the wrapped object implements the interface then the result is the
      * wrapped object or a proxy for the wrapped object. Otherwise return the
-     * the result of calling <code>unwrap</code> recursively on the wrapped object
+     * result of calling <code>unwrap</code> recursively on the wrapped object
      * or a proxy for that result. If the receiver is not a
      * wrapper and does not implement the interface, then an <code>SQLException</code> is thrown.
      *
@@ -2083,4 +2082,9 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
             getMoreResults();
         }
     }
+
+    public int getResultSetScrollability() {
+        return ResultProperties.getJDBCScrollability(rsProperties);
+    }
+
 }
