@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,7 +47,7 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.result.Result;
 
-/* $Id: JDBCUtil.java 5968 2019-04-27 12:55:27Z fredt $ */
+/* $Id: JDBCUtil.java 6266 2021-01-25 16:08:06Z fredt $ */
 
 // campbell-burnet@users - 20060523 - patch 1.9.0 - removed some unused imports
 // Revision 1.16  2006/07/12 11:53:53  boucherb
@@ -95,7 +95,7 @@ public final class JDBCUtil {
         return sqlException(Error.error(id, add));
     }
 
-    static SQLException sqlException(int id, int subId, Object[] add) {
+    static SQLException sqlException(int id, int subId, String[] add) {
         return sqlException(Error.error(null, id, subId, add));
     }
 
