@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,15 +41,21 @@ import java.util.Comparator;
  *
  * @author Tony Lai (tony_lai@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.1
+ * @version 2.6.0
  * @since 1.9.0
  */
-public class ArraySort {
+public final class ArraySort {
 
     /**
-     * Returns the index of the lowest element == the given search target,
-     * or -1
+     * Returns the index of the lowest element == the given search target, or
+     * when not found, a negative value -(insert position + 1)
+     *
      * @return index or a negative value if not found
+     * @param array Object[]
+     * @param start int
+     * @param limit int
+     * @param value Object
+     * @param c Comparator
      */
     public static int searchFirst(Object[] array, int start, int limit,
                                   Object value, Comparator c) {
@@ -104,8 +110,7 @@ public class ArraySort {
         return baseIndex + 1;
     }
 
-    public static void sort(Object[] array, int limit, Comparator comparator
-                            ) {
+    public static void sort(Object[] array, int limit, Comparator comparator) {
 
         if (limit < 2) {
             return;
