@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,32 +31,39 @@
 
 package org.hsqldb.lib;
 
+import java.lang.reflect.Array;
+import java.util.Arrays;
 import java.util.NoSuchElementException;
 
-// fredt@users 20020130 - patch 1.7.0 by fredt - new class
-
 /**
- * jdk 1.1 compatible minimal implementation of a list object suitable for
- * stack, queue and deque usage patterns backed by an Object[].
- * The memory footprint of the HsqlDeque doubles when it gets full
+ * A {@code List<E>} that also implements {@code Deque<E>} and {@code Queue<E>}
+ * and methods for usage as stack.<p>
+ *
+ * When used as {@code Queue<E>}, elements are added to the end of
+ * the List (tail), and retrieved from the start of the List (head).<p>
+ *
+ * When used as a stack, elements are added to and retrieved from the start of
+ * the List (head) using {@code push()} and {@code pop()} methods.<p>
+ *
+ * Data is stored in an Object[] that doubles in size when the List gets full
  * but does not shrink when it gets empty.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.2.9
- * @since 1.7.0
+ * @version 2.6.0
+ * @since 1.7.0, 20020130
  */
-public class HsqlDeque extends BaseList implements HsqlList {
+public class HsqlDeque<E> extends BaseList<E> implements List<E> {
 
-    private Object[] list;
-    private int      firstindex = 0;    // index of first list element
-    private int      endindex   = 0;    // index of last list element + 1
+    private E[] list;
+    private int firstindex = 0;    // index of first list element
+    private int endindex   = 0;    // index of last list element + 1
 
     // can grow to fill list
     // if elementCount == 0 then firstindex == endindex
-    private static final int DEFAULT_INITIAL_CAPACITY = 10;
+    private static final int DEFAULT_INITIAL_CAPACITY = 16;
 
     public HsqlDeque() {
-        list = new Object[DEFAULT_INITIAL_CAPACITY];
+        list = (E[]) new Object[DEFAULT_INITIAL_CAPACITY];
     }
 
     public int size() {
@@ -67,7 +74,42 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return elementCount == 0;
     }
 
-    public Object getFirst() throws NoSuchElementException {
+    public boolean offer(E e) {
+        return add(e); }
+
+    public E remove() {
+        return removeFirst();
+    }
+
+    public E poll() {
+        if(elementCount == 0) {
+            return null;
+        }
+
+        return removeFirst();
+    }
+
+    public E element() {
+        return getFirst();
+    }
+
+    public E peek() {
+        if(elementCount == 0) {
+            return null;
+        }
+
+        return getFirst();
+    }
+
+    public void push(E e) {
+        addFirst(e);
+    }
+
+    public E pop() {
+        return removeFirst();
+    }
+
+    public E getFirst() throws NoSuchElementException {
 
         if (elementCount == 0) {
             throw new NoSuchElementException();
@@ -76,7 +118,7 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return list[firstindex];
     }
 
-    public Object getLast() throws NoSuchElementException {
+    public E getLast() throws NoSuchElementException {
 
         if (elementCount == 0) {
             throw new NoSuchElementException();
@@ -85,14 +127,14 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return list[endindex - 1];
     }
 
-    public Object get(int i) throws IndexOutOfBoundsException {
+    public E get(int i) throws IndexOutOfBoundsException {
 
         int index = getInternalIndex(i);
 
         return list[index];
     }
 
-    public void add(int i, Object o) throws IndexOutOfBoundsException {
+    public void add(int i, E o) throws IndexOutOfBoundsException {
 
         if (i == elementCount) {
             add(o);
@@ -121,23 +163,23 @@ public class HsqlDeque extends BaseList implements HsqlList {
         elementCount++;
     }
 
-    public Object set(int i, Object o) throws IndexOutOfBoundsException {
+    public E set(int i, E o) throws IndexOutOfBoundsException {
 
-        int    index  = getInternalIndex(i);
-        Object result = list[index];
+        int index  = getInternalIndex(i);
+        E   result = list[index];
 
         list[index] = o;
 
         return result;
     }
 
-    public Object removeFirst() throws NoSuchElementException {
+    public E removeFirst() throws NoSuchElementException {
 
         if (elementCount == 0) {
             throw new NoSuchElementException();
         }
 
-        Object o = list[firstindex];
+        E o = list[firstindex];
 
         list[firstindex] = null;
 
@@ -153,7 +195,7 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return o;
     }
 
-    public Object removeLast() throws NoSuchElementException {
+    public E removeLast() throws NoSuchElementException {
 
         if (elementCount == 0) {
             throw new NoSuchElementException();
@@ -161,7 +203,7 @@ public class HsqlDeque extends BaseList implements HsqlList {
 
         endindex--;
 
-        Object o = list[endindex];
+        E o = list[endindex];
 
         list[endindex] = null;
 
@@ -176,16 +218,69 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return o;
     }
 
-/*
-    public Object remove(int i){
-        return get(i);
+    public E peekFirst() {
+        return getFirst();
     }
 
-    public void add(int i, Object o) {
-
+    public E peekLast() {
+        return getLast();
     }
-*/
-    public boolean add(Object o) {
+
+    public boolean offerFirst(E e) {
+        addFirst(e);
+        return true;
+    }
+
+    public boolean offerLast(E e) {
+        addLast(e);
+        return true;
+    }
+
+    public E pollFirst() {
+        if (elementCount == 0) {
+            return null;
+        }
+
+        return removeFirst();
+    }
+
+    public E pollLast() {
+        if (elementCount == 0) {
+            return null;
+        }
+
+        return removeLast();
+    }
+
+    public boolean removeFirstOccurrence(Object o) {
+        int index = indexOf(o);
+
+        if (index < 1) {
+            return false;
+        }
+
+        remove(index);
+
+        return true;
+    }
+
+    public boolean removeLastOccurrence(Object o) {
+        int index = lastIndexOf(o);
+
+        if (index < 1) {
+            return false;
+        }
+
+        remove(index);
+
+        return true;
+    }
+
+    public Iterator<E> descendingIterator() {
+        throw new UnsupportedOperationException();
+    }
+
+    public boolean add(E o) {
 
         resetCapacity();
 
@@ -201,11 +296,11 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return true;
     }
 
-    public boolean addLast(Object o) {
-        return add(o);
+    public void addLast(E o) {
+        add(o);
     }
 
-    public boolean addFirst(Object o) {
+    public void addFirst(E o) {
 
         resetCapacity();
 
@@ -222,8 +317,6 @@ public class HsqlDeque extends BaseList implements HsqlList {
         list[firstindex] = o;
 
         elementCount++;
-
-        return true;
     }
 
     public void clear() {
@@ -234,9 +327,7 @@ public class HsqlDeque extends BaseList implements HsqlList {
 
         firstindex = endindex = elementCount = 0;
 
-        for (int i = 0; i < list.length; i++) {
-            list[i] = null;
-        }
+        Arrays.fill(list, null);
     }
 
     public int indexOf(Object value) {
@@ -252,7 +343,7 @@ public class HsqlDeque extends BaseList implements HsqlList {
                 return i;
             }
 
-            if (value != null && value.equals(list[index])) {
+            if (value != null && comparator.equals(value, list[index])) {
                 return i;
             }
         }
@@ -260,10 +351,32 @@ public class HsqlDeque extends BaseList implements HsqlList {
         return -1;
     }
 
-    public Object remove(int index) {
+    public int lastIndexOf(Object value) {
 
-        int    target = getInternalIndex(index);
-        Object value  = list[target];
+        for (int i = elementCount - 1; i >= 0; i--) {
+            int index = firstindex + i;
+
+            if (index < 0) {
+                index += list.length;
+            }
+
+            if (list[index] == value) {
+                return i;
+            }
+
+            if (value != null && comparator.equals(value, list[index])) {
+                return i;
+            }
+        }
+
+        return -1;
+    }
+
+
+    public E remove(int index) {
+
+        int target = getInternalIndex(index);
+        E   value  = list[target];
 
         if (target == firstindex) {
             list[firstindex] = null;
@@ -338,10 +451,15 @@ public class HsqlDeque extends BaseList implements HsqlList {
             endindex = list.length + endindex;
         }
 
-        list = newList;
+        list = (E[]) newList;
     }
 
-    public void toArray(Object[] array) {
+    public <T> T[] toArray(T[] array) {
+
+        if (array.length < elementCount) {
+            array = (T[]) Array.newInstance(array.getClass().getComponentType(),
+                                        elementCount);
+        }
 
         int tempCount = list.length - firstindex;
 
@@ -353,8 +471,35 @@ public class HsqlDeque extends BaseList implements HsqlList {
 
         if (endindex <= firstindex) {
             System.arraycopy(list, 0, array, tempCount, endindex);
-
-            endindex = list.length + endindex;
         }
+
+        return array;
+    }
+
+    public Object[] toArray() {
+
+        Object[] newArray = new Object[elementCount];
+
+        return toArray(newArray);
+    }
+
+    public List<E> subList(int fromIndex, int toIndex) {
+        throw new UnsupportedOperationException();
+    }
+
+    public boolean containsAll(Collection c) {
+        throw new UnsupportedOperationException();
+    }
+
+    public boolean removeAll(Collection c) {
+        throw new UnsupportedOperationException();
+    }
+
+    public boolean retainAll(Collection c) {
+        throw new UnsupportedOperationException();
+    }
+
+    public boolean addAll(int index, Collection c) {
+        throw new UnsupportedOperationException();
     }
 }
