@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -53,7 +53,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * Implementation of RowSetNavigator for result sets.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class RowSetNavigatorData extends RowSetNavigator
@@ -81,11 +81,15 @@ implements Comparator<Object[]> {
     Index idIndex;
 
     //
-    TreeMap<Object[], Integer> rowMap;
+    final SortAndSlice sortAndSlice;
+
+    //
+    TreeMap<Object[], Integer> groupMap;
     LongKeyHashMap             idMap;
 
-    RowSetNavigatorData(Session session) {
+    RowSetNavigatorData(Session session, SortAndSlice sortAndSlice) {
         this.session = session;
+        this.sortAndSlice = sortAndSlice;
     }
 
     public RowSetNavigatorData(Session session, QuerySpecification select) {
@@ -97,10 +101,11 @@ implements Comparator<Object[]> {
         mainIndex          = select.mainIndex;
         fullIndex          = select.fullIndex;
         orderIndex         = select.orderIndex;
+        sortAndSlice       = select.sortAndSlice;
 
         if (select.isGrouped) {
             mainIndex = select.groupIndex;
-            rowMap    = new TreeMap<Object[], Integer>(this);
+            groupMap    = new TreeMap<Object[], Integer>(this);
         }
 
         if (select.idIndex != null) {
@@ -116,11 +121,13 @@ implements Comparator<Object[]> {
         fullIndex          = queryExpression.fullIndex;
         orderIndex         = queryExpression.orderIndex;
         visibleColumnCount = queryExpression.getColumnCount();
+        sortAndSlice       = queryExpression.sortAndSlice;
     }
 
     public RowSetNavigatorData(Session session, RowSetNavigator navigator) {
 
         this.session = session;
+        sortAndSlice = SortAndSlice.noSort;
 
         setCapacity(navigator.size);
 
@@ -164,8 +171,8 @@ implements Comparator<Object[]> {
 
         dataTable[size] = data;
 
-        if (rowMap != null) {
-            rowMap.put(data, size);
+        if (groupMap != null) {
+            groupMap.put(data, size);
         }
 
         if (idMap != null) {
@@ -179,7 +186,7 @@ implements Comparator<Object[]> {
 
     public void setPosition(Object[] data) {
 
-        Integer mapPos = rowMap.get(data);
+        Integer mapPos = groupMap.get(data);
 
         if (mapPos == null) {
             return;
@@ -207,7 +214,7 @@ implements Comparator<Object[]> {
     }
 
     void insertAdjusted(Object[] data, int[] columnMap) {
-        projectData(data, columnMap);
+        data = projectData(data, columnMap);
         insert(data);
     }
 
@@ -264,7 +271,7 @@ implements Comparator<Object[]> {
     }
 
     public void resetRowMap() {
-        rowMap = new TreeMap(this);
+        groupMap = new TreeMap(this);
     }
 
     public boolean absolute(int position) {
@@ -304,6 +311,20 @@ implements Comparator<Object[]> {
         size--;
     }
 
+    public void removeRange(int start, int rows) {
+
+        ArrayUtil.adjustArray(ArrayUtil.CLASS_CODE_OBJECT, dataTable, size,
+                              start, -rows);
+
+        if (currentPos >= start + rows) {
+            currentPos -= rows;
+        } else if (currentPos >= start) {
+            currentPos = start;
+        }
+
+        size -= rows;
+    }
+
     public void reset() {
         super.reset();
     }
@@ -460,6 +481,23 @@ implements Comparator<Object[]> {
         reset();
     }
 
+    public void exceptNoDedup(RowSetNavigatorData other) {
+
+        other.sortFull();
+        reset();
+
+        while (next()) {
+            Object[] currentData = getCurrent();
+            boolean  hasRow      = other.containsRow(currentData);
+
+            if (hasRow) {
+                removeCurrent();
+            }
+        }
+
+        reset();
+    }
+
     public void exceptAll(RowSetNavigatorData other) {
 
         Object[]    compareData = null;
@@ -572,30 +610,13 @@ implements Comparator<Object[]> {
             return;
         }
 
-        if (limitstart != 0) {
+        if ((long) limitstart + limitcount < size) {
             reset();
-
-            for (int i = 0; i < limitstart; i++) {
-                next();
-                removeCurrent();
-            }
+            removeRange(limitstart + limitcount,
+                        size - limitstart - limitcount);
         }
 
-        if (limitcount >= size) {
-            return;
-        }
-
-        reset();
-
-        for (int i = 0; i < limitcount; i++) {
-            next();
-        }
-
-        while (next()) {
-            removeCurrent();
-        }
-
-        reset();
+        removeRange(0, limitstart);
     }
 
     boolean hasNull(Object[] data) {
@@ -624,7 +645,7 @@ implements Comparator<Object[]> {
             return simpleAggregateData;
         }
 
-        Integer position = rowMap.get(data);
+        Integer position = groupMap.get(data);
 
         if (position == null) {
             return null;
@@ -640,7 +661,7 @@ implements Comparator<Object[]> {
      */
     public Object[] getGroupDataAndPosition(Object[] data) {
 
-        Integer mapPos = rowMap.get(data);
+        Integer mapPos = groupMap.get(data);
 
         if (mapPos == null) {
             return null;
