@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ import org.hsqldb.rowio.RowInputInterface;
  * Interface for a store for CachedObject objects.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public interface PersistentStore {
@@ -133,6 +133,8 @@ public interface PersistentStore {
 
     CachedObject getAccessor(Index key);
 
+    void setAccessors(long base, long[] accessors, long cardinality);
+
     void setAccessor(Index key, CachedObject accessor);
 
     void setAccessor(Index key, long accessor);
@@ -145,8 +147,6 @@ public interface PersistentStore {
 
     long elementCountUnique(Index index);
 
-    void setElementCount(Index key, long size, long uniqueSize);
-
     boolean hasNull(int pos);
 
     void resetAccessorKeys(Session session, Index[] keys);
