@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -205,7 +205,7 @@ class OdbcPacketInputStream extends DataInputStream {
 
         try {
             return (len < 0) ? null
-                             : new BinaryData((long) len, this);
+                             : new BinaryData(len, this);
         } catch (HsqlException he) {
             throw new IOException(he.getMessage());
         }
