@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -80,7 +80,7 @@ import org.hsqldb.rowio.RowOutputBinary;
  *  (fredt@users)
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.0
  * @since 1.6.2
  */
 class WebServerConnection implements Runnable {
@@ -339,8 +339,7 @@ class WebServerConnection implements Runnable {
                         DatabaseManager.newSession(dbID,
                                                    resultIn.getMainString(),
                                                    resultIn.getSubString(),
-                                                   resultIn.getZoneString(),
-                                                   resultIn.getUpdateCount());
+                                                   resultIn.getZoneString());
                     resultOut =
                         Result.newConnectionAcknowledgeResponse(session);
                 } catch (HsqlException e) {
