@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.lang.reflect.Method;
 import org.hsqldb.test.TestUtil;
-import org.hsqldb.lib.RCData;
+import org.hsqldb.util.RCData;
 
 /**
  * @see #main
