@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ public class TestSqlPersistent extends TestCase {
 
     // change the url to reflect your preferred db location and name
 //    String url = "jdbc:hsqldb:hsql://localhost/mytest";
-    String     url = "jdbc:hsqldb:/hsql/test/testpersistent";
+    String     url = TestDirectorySettings.fileBaseURL + "test/testpersistent";
     String     user;
     String     password;
     Statement  stmnt;
@@ -73,7 +73,7 @@ public class TestSqlPersistent extends TestCase {
         stmnt      = null;
         connection = null;
 
-        TestUtil.deleteDatabase("/hsql/test/testpersistent");
+        TestUtil.deleteDatabase(TestDirectorySettings.fileBase + "test/testpersistent");
 
         try {
             Class.forName("org.hsqldb.jdbc.JDBCDriver");
@@ -90,7 +90,7 @@ public class TestSqlPersistent extends TestCase {
     /**
      *  demonstration of bug fix #482109 - inserting Integers
      *  and Strings with PreparedStatement.setObject() did not work;
-     *  String, Integer and Array types are inserted and retrieved<b>
+     *  String, Integer and Array types are inserted and retrieved<p>
      *
      *  demonstration of retrieving values using different getXXX methods
      */
@@ -216,7 +216,6 @@ public class TestSqlPersistent extends TestCase {
                 System.out.print((char) c);
             }
 
-
             // retrieving objects inserted into the third column
             stringValueResult = rs.getObject(3);
 
