@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ public class TestViewAsterisks extends TestBase {
 
     /** Creates a new instance of TestViewAsterisks */
     public TestViewAsterisks(String testName) {
-        super(testName, null, false, false);
+        super(testName);
     }
 
     /**
@@ -244,7 +244,7 @@ public class TestViewAsterisks extends TestBase {
      *
      *  @param viewName
      *      the name of the to-be-created view
-     *  @param columnNames
+     *  @param columnList
      *      the names of the columns of the view, as to be specified in the CREATE VIEW statement. Might be null,
      *      in this case the view will be created without an explicit column list
      *  @param viewStatement
