@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,7 +47,7 @@ import org.hsqldb.lib.StringUtil;
  * Type subclass for CHARACTER, VARCHAR, etc.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class CharacterType extends Type {
@@ -281,7 +281,6 @@ public class CharacterType extends Type {
             case Types.OTHER :
                 throw Error.error(ErrorCode.X_42562);
             default :
-
                 /*
                  * @todo - this seems to be allowed in SQL-92 (is in NIST)
                  * but is disallowed in SQL:2003
@@ -417,14 +416,18 @@ public class CharacterType extends Type {
 
         switch (typeCode) {
 
-            case Types.SQL_CHAR : {
+            case Types.SQL_CHAR :
+            case Types.SQL_VARCHAR : {
                 int slen = ((String) a).length();
 
-                if (slen == precision) {
-                    return a;
-                }
-
                 if (slen > precision) {
+                    if (session instanceof Session) {
+                        if (!((Session) session).database
+                                .sqlTruncateTrailing) {
+                            throw Error.error(ErrorCode.X_22001);
+                        }
+                    }
+
                     if (getRightTrimSize((String) a, ' ') <= precision) {
                         return ((String) a).substring(0, (int) precision);
                     } else {
@@ -432,6 +435,14 @@ public class CharacterType extends Type {
                     }
                 }
 
+                if (typeCode == Types.SQL_VARCHAR) {
+                    return a;
+                }
+
+                if (slen == precision) {
+                    return a;
+                }
+
                 char[] b = new char[(int) precision];
 
                 ((String) a).getChars(0, slen, b, 0);
@@ -442,19 +453,6 @@ public class CharacterType extends Type {
 
                 return new String(b);
             }
-            case Types.SQL_VARCHAR : {
-                int slen = ((String) a).length();
-
-                if (slen > precision) {
-                    if (getRightTrimSize((String) a, ' ') <= precision) {
-                        return ((String) a).substring(0, (int) precision);
-                    } else {
-                        throw Error.error(ErrorCode.X_22001);
-                    }
-                }
-
-                return a;
-            }
             case Types.SQL_CLOB : {
                 ClobData clob = (ClobData) a;
 
@@ -652,7 +650,7 @@ public class CharacterType extends Type {
         } else if (a instanceof java.util.UUID) {
             s = a.toString();
         } else {
-            s = convertJavaTimeObject(session, a);
+            s = convertJavaDateTimeObject(a);
 
             if (s == null) {
                 throw Error.error(ErrorCode.X_42561);
@@ -663,7 +661,7 @@ public class CharacterType extends Type {
     }
 
 //#ifdef JAVA8
-    String convertJavaTimeObject(SessionInterface session, Object a) {
+    String convertJavaDateTimeObject(Object a) {
 
         switch(a.getClass().getName()){
             case "java.time.LocalDate":
@@ -680,7 +678,7 @@ public class CharacterType extends Type {
 
 //#else
 /*
-    String convertJavaTimeObject(SessionInterface session, Object a) {
+    String convertJavaDateTimeObject(Object a) {
         return null;
     }
 */
@@ -734,6 +732,17 @@ public class CharacterType extends Type {
         return StringConverter.toQuotedString(s, '\'', true);
     }
 
+    public void convertToJSON(Object a, StringBuilder sb) {
+
+        if (a == null) {
+            sb.append("null");
+
+            return;
+        }
+
+        StringConverter.toJSONString((String) a, sb);
+    }
+
     public boolean canConvertFrom(Type otherType) {
         return !otherType.isObjectType();
     }
@@ -748,32 +757,32 @@ public class CharacterType extends Type {
 
             case Types.SQL_VARCHAR : {
                 if (otherType.typeCode == typeCode) {
-                    return precision >= otherType.precision ? 0
-                                                            : 1;
+                    return precision >= otherType.precision ? ReType.keep
+                                                            : ReType.check;
                 }
 
                 if (otherType.typeCode == Types.SQL_CHAR) {
-                    return precision >= otherType.precision ? 0
-                                                            : -1;
+                    return precision >= otherType.precision ? ReType.keep
+                                                            : ReType.change;
                 }
 
                 return -1;
             }
             case Types.SQL_CLOB : {
                 if (otherType.typeCode == Types.SQL_CLOB) {
-                    return precision >= otherType.precision ? 0
-                                                            : 1;
+                    return precision >= otherType.precision ? ReType.keep
+                                                            : ReType.check;
                 }
 
                 return -1;
             }
             case Types.SQL_CHAR : {
                 return otherType.typeCode == Types.SQL_CHAR
-                       && precision == otherType.precision ? 0
-                                                           : -1;
+                       && precision == otherType.precision ? ReType.keep
+                                                           : ReType.change;
             }
             default :
-                return -1;
+                return ReType.change;
         }
     }
 
@@ -838,66 +847,60 @@ public class CharacterType extends Type {
         }
     }
 
+    /**
+     * length must not be negative
+     */
+    public static LongPair substringParams(long dataLength, long start,
+                                           long length, boolean hasLength) {
+
+        long end;
+
+        if (hasLength) {
+            end = start + length;
+        } else {
+            end = Math.max(dataLength, start);
+        }
+
+        // trim
+        if (start >= dataLength || end < 0) {
+            start  = 0;
+            length = 0;
+        } else {
+            start  = Math.max(start, 0);
+            end    = Math.min(end, dataLength);
+            length = end - start;
+        }
+
+        return new LongPair(start, length);
+    }
+
     public Object substring(SessionInterface session, Object data,
                             long offset, long length, boolean hasLength,
                             boolean trailing) {
 
-        long end;
+        if (length < 0) {
+            throw Error.error(ErrorCode.X_22011);
+        }
+
         long dataLength = typeCode == Types.SQL_CLOB
                           ? ((ClobData) data).length(session)
                           : ((String) data).length();
 
         if (trailing) {
-            end = dataLength;
-
-            if (length > dataLength) {
-                offset = 0;
-            } else {
-                offset = dataLength - length;
-            }
-        } else if (hasLength) {
-            end = offset + length;
-        } else {
-            end = dataLength > offset ? dataLength
-                                      : offset;
+            offset = dataLength - offset;
         }
 
-        if (end < offset) {
-            throw Error.error(ErrorCode.X_22011);
-        }
+        LongPair segment = substringParams(dataLength, offset, length,
+                                           hasLength);
 
-        if (end < 0) {
-
-            // return zero length data
-            offset = 0;
-            end    = 0;
-        }
-
-        if (offset < 0) {
-            offset = 0;
-        }
-
-        if (end > dataLength) {
-            end = dataLength;
-        }
-
-        length = end - offset;
+        offset = segment.a;
+        length = segment.b;
 
         if (data instanceof String) {
             return ((String) data).substring((int) offset,
                                              (int) (offset + length));
         } else if (data instanceof ClobData) {
-            ClobData clob = session.createClob(length);
-
-            if (length > Integer.MAX_VALUE) {
-                throw Error.error(ErrorCode.X_22001);
-            }
-
-            /* @todo - change to support long strings */
-            String result = ((ClobData) data).getSubString(session, offset,
-                (int) length);
-
-            clob.setString(session, 0, result);
+            ClobData clob = ((ClobData) data).getClob(session, offset, length);
 
             return clob;
         } else {
