@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -53,6 +53,13 @@ import org.hsqldb.rights.Grantee;
  */
 public abstract class Type implements SchemaObject, Cloneable {
 
+    public interface ReType {
+
+        int keep   = 0;     // only metadata change is required
+        int check  = 1;     // range check is also required
+        int change = -1;    // data conversion is required
+    }
+
     public static final Type[] emptyArray = new Type[]{};
 
     //
@@ -334,6 +341,19 @@ public abstract class Type implements SchemaObject, Cloneable {
 
     public abstract String convertToSQLString(Object a);
 
+    public void convertToJSON(Object a, StringBuilder sb) {
+
+        if (a == null) {
+            sb.append("null");
+
+            return;
+        }
+
+        String val = convertToString(a);
+
+        sb.append(val);
+    }
+
     public abstract boolean canConvertFrom(Type otherType);
 
     /**
@@ -343,10 +363,10 @@ public abstract class Type implements SchemaObject, Cloneable {
     public int canMoveFrom(Type otherType) {
 
         if (otherType == this) {
-            return 0;
+            return ReType.keep;
         }
 
-        return -1;
+        return ReType.change;
     }
 
     public boolean canBeAssignedFrom(Type otherType) {
@@ -631,6 +651,8 @@ public abstract class Type implements SchemaObject, Cloneable {
     public static final CharacterType SQL_VARCHAR_DEFAULT =
         new CharacterType(Types.SQL_VARCHAR,
                           CharacterType.defaultVarcharPrecision);
+    public static final CharacterType SQL_VARCHAR_LONG =
+        new CharacterType(Types.SQL_VARCHAR, ClobType.defaultShortClobSize);
     public static final ClobType SQL_CLOB =
         new ClobType(ClobType.defaultClobSize);
 
