@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2021, The HSQL Development Group
+ * Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -227,9 +227,7 @@ final class DatabaseManagerCommon {
             // drop table may fail
             try {
                 sStatement.execute(demo[i]);
-            } catch (SQLException e) {
-                ;
-            }
+            } catch (SQLException e) {}
         }
     }
 
